@@ -35,8 +35,8 @@
 #include "position.h"
 #include "color.h"
 #include "cell.h"
-#include "cell-comment.h"
 #include "sheet-object.h"
+#include "sheet-object-cell-comment.h"
 #include "style.h"
 #include "format.h"
 #include "main.h"
@@ -262,11 +262,17 @@ write_magic_interface (BiffPut *bp, MsBiffVersion ver)
 	}
 }
 
-/* FIXME: Not sure if name should be quoted or not */
+/*
+ * XL doesn't write externsheets as often as we do. The previous version of
+ * this function causes XL to crash when we exported a spreadsheet function
+ * which is not an XL builtin. This version is still wrong, but won't crash
+ * XL. 
+ */
 static void
 write_externsheets (BiffPut *bp, ExcelWorkbook *wb, ExcelSheet *ignore)
 {
 	guint32 num_sheets = wb->sheets->len;
+	guint32 externcount;
 	guint8 *data;
 	int lp;
 
@@ -275,13 +281,22 @@ write_externsheets (BiffPut *bp, ExcelWorkbook *wb, ExcelSheet *ignore)
 		return;
 	}
 
-	if (ignore) /* Strangely needed */
-		num_sheets--;
-
 	g_assert (num_sheets < 0xffff);
 
+	/* Kluge upon kluge, but the externcount will now match the number
+	 * of externsheets we store. */
+	for (lp = 0, externcount = 0; lp < num_sheets; lp++) {
+		ExcelSheet *sheet = g_ptr_array_index (wb->sheets, lp);
+
+		if (sheet != ignore)
+			externcount ++;
+	}
+
+	if (externcount == 0)
+		return;
+	
 	data = ms_biff_put_len_next (bp, BIFF_EXTERNCOUNT, 2);
-	MS_OLE_SET_GUINT16(data, num_sheets);
+	MS_OLE_SET_GUINT16(data, externcount);
 	ms_biff_put_commit (bp);
 
 	for (lp = 0; lp < num_sheets; lp++) {
@@ -2444,20 +2459,26 @@ static void
 write_biff7_comments (BiffPut *bp, ExcelSheet *sheet)
 {
 	guint8 data[6];
-	GList *l;
-	Sheet *gnum_sheet = sheet->gnum_sheet;
+	GList *l, *comments;
 	MsBiffVersion ver = sheet->wb->ver;
 
-	 for (l = gnum_sheet->comment_list; l; l = l->next) {
-		Cell *cell = l->data;
-		char *comment = cell_get_comment (cell);
-		guint16 row = cell->pos.row;
-		guint16 col = cell->pos.col;
-		guint16 len = strlen (comment);
+	comments = sheet_get_objects (sheet->gnum_sheet, NULL,
+				      CELL_COMMENT_TYPE);
 
+	for (l = comments; l; l = l->next) {
+		CellComment *cc = l->data;
+		char *comment = (char *)cell_comment_text_get (cc);
+		Range const *pos = sheet_object_range_get (SHEET_OBJECT (cc));
+
+		guint16 len;
+
+		g_return_if_fail (comment != NULL);
+		g_return_if_fail (pos != NULL);
+
+		len = strlen (comment);
 		ms_biff_put_var_next (bp, BIFF_NOTE);
-		MS_OLE_SET_GUINT16 (data + 0, row);
-		MS_OLE_SET_GUINT16 (data + 2, col);
+		MS_OLE_SET_GUINT16 (data + 0, pos->start.row);
+		MS_OLE_SET_GUINT16 (data + 2, pos->start.col);
 		MS_OLE_SET_GUINT16 (data + 4, len);
 		ms_biff_put_var_write (bp, data, 6);
 
@@ -2474,11 +2495,11 @@ repeat:
 			comment += MAX_BIFF_NOTE_CHUNK;
 			len -= MAX_BIFF_NOTE_CHUNK;
 
-	        	ms_biff_put_var_next (bp, BIFF_NOTE);
-		        MS_OLE_SET_GUINT16 (data + 0, 0xffff);
-	        	MS_OLE_SET_GUINT16 (data + 2, 0);
-		        MS_OLE_SET_GUINT16 (data + 4, MIN (MAX_BIFF_NOTE_CHUNK, len));
-		        ms_biff_put_var_write (bp, data, 6);
+			ms_biff_put_var_next (bp, BIFF_NOTE);
+			MS_OLE_SET_GUINT16 (data + 0, 0xffff);
+			MS_OLE_SET_GUINT16 (data + 2, 0);
+			MS_OLE_SET_GUINT16 (data + 4, MIN (MAX_BIFF_NOTE_CHUNK, len));
+			ms_biff_put_var_write (bp, data, 6);
 
 			goto repeat;
 		} else {
@@ -2486,6 +2507,7 @@ repeat:
 			ms_biff_put_commit (bp);
 		}
 	}
+	g_list_free (comments);
 }
 
 /**
