@@ -610,7 +610,7 @@ write_node (PolishData *pd, ExprTree *tree)
 				ms_biff_put_var_write (pd->bp, data, 3);
 			} else {
 				MS_OLE_SET_GUINT8 (data, FORMULA_PTG_NUM);
-				BIFF_SETDOUBLE (data + 1, value_get_as_float (v));
+				gnumeric_set_le_double (data + 1, value_get_as_float (v));
 				ms_biff_put_var_write (pd->bp, data, 9);
 			}
 			break;
@@ -619,7 +619,7 @@ write_node (PolishData *pd, ExprTree *tree)
 		{
 			guint8 data[10];
 			MS_OLE_SET_GUINT8 (data, FORMULA_PTG_NUM);
-			BIFF_SETDOUBLE (data+1, value_get_as_float (v));
+			gnumeric_set_le_double (data+1, value_get_as_float (v));
 			ms_biff_put_var_write (pd->bp, data, 9);
 			break;
 		}
@@ -768,7 +768,7 @@ write_arrays (PolishData *pd)
 
 			if (VALUE_IS_NUMBER (v)) {
 				push_guint8 (pd, 1);
-				BIFF_SETDOUBLE (data, value_get_as_float (v));
+				gnumeric_set_le_double (data, value_get_as_float (v));
 				ms_biff_put_var_write (pd->bp, data, 8);
 			} else { /* Can only be a string */
 				gchar *txt = value_get_as_string (v);
