@@ -85,11 +85,18 @@ generic_marshaller (FunctionEvalInfo *ei, GList *nodes)
 	g_return_val_if_fail (wd != NULL, NULL);
 
 	{ /* Register Excel objects with GB */
+		/* FIXME: the way these objects are exposed is really wierd */
 		application = excel_gb_application_new (ei->pos->sheet->workbook);
-		gbrun_project_register_object (wd->proj, GBRUN_OBJECT (application));
+		gbrun_project_register_module (
+			wd->proj, GB_OBJECT (application));
+		gbrun_project_register_object (
+			wd->proj, "Workbook", GBRUN_OBJECT (application));
 
 		worksheet = excel_gb_worksheet_new (ei->pos->sheet);
-		gbrun_project_register_object (wd->proj, GBRUN_OBJECT (worksheet));
+		gbrun_project_register_module (
+			wd->proj, GB_OBJECT (worksheet));
+		gbrun_project_register_object (
+			wd->proj, "Worksheet", GBRUN_OBJECT (worksheet));
 	}
 
 	for (l = nodes; l; l = l->next) {
@@ -133,11 +140,12 @@ generic_marshaller (FunctionEvalInfo *ei, GList *nodes)
 	}
 
 	{ /* De-Register Excel objects with GB */
-		gbrun_project_deregister_object (wd->proj, GBRUN_OBJECT (application));
-		gtk_object_unref (GTK_OBJECT (application));
-
-		gbrun_project_deregister_object (wd->proj, GBRUN_OBJECT (worksheet));
-		gtk_object_unref (GTK_OBJECT (worksheet));
+		gbrun_project_deregister_module (wd->proj, GB_OBJECT (application));
+		gbrun_project_deregister_module (wd->proj, GB_OBJECT (worksheet));
+		gb_object_unref (GB_OBJECT (application));
+		gb_object_unref (GB_OBJECT (worksheet));
+		gbrun_project_deregister_object (wd->proj, "Workbook");
+		gbrun_project_deregister_object (wd->proj, "Worksheet");
 	}
 
 	return ans;
