@@ -25,13 +25,13 @@
 #include "gnumeric.h"
 #include "gnumeric-util.h"
 
-int html_write_wb_html32 (CommandContext *context, Workbook *wb,
+int html_write_wb_html32 (IOContext *context, WorkbookView *wb_view,
 			  const char *filename);
-int html_write_wb_html40 (CommandContext *context, Workbook *wb,
+int html_write_wb_html40 (IOContext *context, WorkbookView *wb_view,
+			  const char *filename);
+int html_read		 (IOContext *context, WorkbookView *view,
 			  const char *filename);
-int html_read (CommandContext *context, Workbook *wb, const char *filename);
 
 #define G_PLUGIN_FOR_HTML "GPFH/0.5"
 
 #endif
-
