@@ -32,15 +32,13 @@ enum {
 typedef enum {
 	CELL_COPY_TYPE_CELL,
 	CELL_COPY_TYPE_TEXT,
-	CELL_COPY_TYPE_TEXT_AND_COMMENT,
 } CellCopyType;
 
 typedef struct {
 	int col_offset, row_offset; /* Position of the cell */
 	CellCopyType type;
-	char *comment;
 	union {
-		Cell   *cell;
+		Cell *cell;
 		char *text;
 	} u;
 } CellCopy;
