@@ -93,6 +93,7 @@ typedef struct
 {
 	GtkObject parent;
 	char const *cmd_descriptor;	/* A string to put in the menu */
+	int size;                       /* See truncate_undo_info.  */
 } GnumericCommand;
 
 typedef gboolean (* UndoCmd)(GnumericCommand *this, WorkbookControl *wbc);
@@ -127,22 +128,22 @@ gnumeric_command_destroy (GtkObject *obj)
 	(*gtk_object_dtor) (obj);
 }
 
-#define GNUMERIC_MAKE_COMMAND(type, func) \
-static gboolean \
-func ## _undo (GnumericCommand *me, WorkbookControl *wbc); \
-static gboolean \
-func ## _redo (GnumericCommand *me, WorkbookControl *wbc); \
-static void \
-func ## _destroy (GtkObject *object); \
-static void \
-func ## _class_init (GnumericCommandClass * const parent) \
-{	\
-	parent->undo_cmd = (UndoCmd)& func ## _undo;		\
-	parent->redo_cmd = (RedoCmd)& func ## _redo;		\
-	if (gtk_object_dtor == NULL)				\
-		gtk_object_dtor = parent->parent_class.destroy;	\
-	parent->parent_class.destroy = & func ## _destroy;	\
-} \
+#define GNUMERIC_MAKE_COMMAND(type, func)				\
+static gboolean								\
+func ## _undo (GnumericCommand *me, WorkbookControl *wbc);		\
+static gboolean								\
+func ## _redo (GnumericCommand *me, WorkbookControl *wbc);		\
+static void								\
+func ## _destroy (GtkObject *object);					\
+static void								\
+func ## _class_init (GnumericCommandClass * const parent)		\
+{									\
+	parent->undo_cmd = (UndoCmd)& func ## _undo;			\
+	parent->redo_cmd = (RedoCmd)& func ## _redo;			\
+	if (gtk_object_dtor == NULL)					\
+		gtk_object_dtor = parent->parent_class.destroy;		\
+	parent->parent_class.destroy = & func ## _destroy;		\
+}									\
 static GNUMERIC_MAKE_TYPE_WITH_CLASS(func, #type, type, GnumericCommandClass, func ## _class_init, NULL, \
 				     gnumeric_command_get_type())
 
@@ -205,7 +206,7 @@ command_undo (WorkbookControl *wbc)
 	cmd = GNUMERIC_COMMAND (wb->undo_commands->data);
 	g_return_if_fail (cmd != NULL);
 
-	klass = GNUMERIC_COMMAND_CLASS(cmd->parent.klass);
+	klass = GNUMERIC_COMMAND_CLASS (cmd->parent.klass);
 	g_return_if_fail (klass != NULL);
 
 	/* TRUE indicates a failure to undo.  Leave the command where it is */
@@ -245,7 +246,7 @@ command_redo (WorkbookControl *wbc)
 	cmd = GNUMERIC_COMMAND (wb->redo_commands->data);
 	g_return_if_fail (cmd != NULL);
 
-	klass = GNUMERIC_COMMAND_CLASS(cmd->parent.klass);
+	klass = GNUMERIC_COMMAND_CLASS (cmd->parent.klass);
 	g_return_if_fail (klass != NULL);
 
 	/* TRUE indicates a failure to redo.  Leave the command where it is */
@@ -287,6 +288,81 @@ command_list_release (GSList *cmd_list)
 	}
 }
 
+/*
+ * Each undo item has a certain size.  The size of typing a value into
+ * a cell is the unit size.  A large autoformat could have a size of
+ * hundreds or even thousands.
+ *
+ * We wish to have the same undo behaviour across platforms, so please
+ * don't use sizeof in computing the undo size.
+ */
+
+#undef DEBUG_TRUNCATE_UNDO
+
+/*
+ * Truncate the undo list if it is too big.
+ *
+ * Returns -1 if no truncation was done, or else the number of elements
+ * left.
+ */
+static int
+truncate_undo_info (WorkbookControl *wbc)
+{
+	int size_left = 100; /* FIXME? */
+	int ok_count;
+	GSList *l, *prev;
+	Workbook *wb = wb_control_workbook (wbc);
+
+#ifdef DEBUG_TRUNCATE_UNDO
+	fprintf (stderr, "Undo sizes:");
+#endif
+
+	for (l = wb->undo_commands, prev = NULL, ok_count = 0;
+	     l;
+	     prev = l, l = l->next, ok_count++) {
+		int min_leave;
+		GnumericCommand *cmd = GNUMERIC_COMMAND (l->data);
+		int size = cmd->size;
+
+		if (size < 1) {
+				/*
+				 * We could g_assert, but that would cause data loss.
+				 * Instead, just continue.
+				 */
+			g_warning ("Faulty undo_size_func, please report.");
+			size = 1;
+		}
+
+#ifdef DEBUG_TRUNCATE_UNDO
+			fprintf (stderr, " %d", size);
+#endif
+
+		/* Keep at least one undo item.  */
+		if (size > size_left && ok_count >= 1) {
+			/* Current item is too big; truncate list here.  */
+			command_list_release (l);
+			prev->next = NULL;
+#ifdef DEBUG_TRUNCATE_UNDO
+			fprintf (stderr, "[trunc]\n");
+#endif
+			return ok_count;
+		}
+
+		/*
+		 * In order to allow a series of useful small items behind
+		 * a big item, leave at least 10% of current item's size.
+		 */
+		min_leave = size / 10;
+		size_left = MAX (size_left - size, min_leave);
+	}
+
+#ifdef DEBUG_TRUNCATE_UNDO
+	fprintf (stderr, "\n");
+#endif
+	return -1;
+}
+
+
 /**
  * command_push_undo : An internal utility to tack a new command
  *    onto the undo list.
@@ -309,23 +385,29 @@ command_push_undo (WorkbookControl *wbc, GtkObject *obj)
 	cmd = GNUMERIC_COMMAND (obj);
 	g_return_val_if_fail (cmd != NULL, TRUE);
 
-	klass = GNUMERIC_COMMAND_CLASS(cmd->parent.klass);
+	klass = GNUMERIC_COMMAND_CLASS (cmd->parent.klass);
 	g_return_val_if_fail (klass != NULL, TRUE);
 
 	/* TRUE indicates a failure to do the command */
 	trouble = klass->redo_cmd (cmd, wbc);
 
 	if  (!trouble) {
+		int undo_trunc;
+
 		command_list_release (wb->redo_commands);
 		wb->redo_commands = NULL;
 
 		wb->undo_commands = g_slist_prepend (wb->undo_commands, cmd);
+		undo_trunc = truncate_undo_info (wbc);
 
 		WORKBOOK_FOREACH_CONTROL (wb, view, control,
 		{
 			wb_control_undo_redo_push (control,
 						   cmd->cmd_descriptor, TRUE);
+			if (undo_trunc >= 0)
+				wb_control_undo_redo_truncate (control, undo_trunc, TRUE);
 			wb_control_undo_redo_clear (control, FALSE);
+				
 		});
 		undo_redo_menu_labels (wb);
 	} else
@@ -352,7 +434,7 @@ GNUMERIC_MAKE_COMMAND (CmdSetText, cmd_set_text);
 static gboolean
 cmd_set_text_undo (GnumericCommand *cmd, WorkbookControl *wbc)
 {
-	CmdSetText *me = CMD_SET_TEXT(cmd);
+	CmdSetText *me = CMD_SET_TEXT (cmd);
 	Cell *cell;
 	char *new_text;
 
@@ -400,7 +482,7 @@ cmd_set_text_redo (GnumericCommand *cmd, WorkbookControl *wbc)
 static void
 cmd_set_text_destroy (GtkObject *cmd)
 {
-	CmdSetText *me = CMD_SET_TEXT(cmd);
+	CmdSetText *me = CMD_SET_TEXT (cmd);
 	if (me->text != NULL) {
 		g_free (me->text);
 		me->text = NULL;
@@ -449,9 +531,11 @@ cmd_set_text (WorkbookControl *wbc,
 	} else
 		text = corrected_text;
 
+	me->parent.size = 1;
+
 	me->parent.cmd_descriptor =
 		g_strdup_printf (_("Typing \"%s%s\" in %s"), text, pad,
-				 cell_pos_name(pos));
+				 cell_pos_name (pos));
 
 	if (text != corrected_text)
 		g_free (text);
@@ -628,13 +712,15 @@ cmd_area_set_text (WorkbookControl *wbc, EvalPos const *pos,
 	me->selection   = selection_get_ranges (pos->sheet, FALSE /* No intersection */);
 	me->old_content = NULL;
 
-	if (strlen(new_text) > MAX_DESCRIPTOR_WIDTH) {
+	if (strlen (new_text) > MAX_DESCRIPTOR_WIDTH) {
 		pad = "..."; /* length of 3 */
 		text = g_strndup (new_text,
 				  MAX_DESCRIPTOR_WIDTH - 3);
 	} else
 		text = (gchar *) new_text;
 
+	me->parent.size = 1;
+
 	me->parent.cmd_descriptor =
 	    g_strdup_printf (_("Typing \"%s%s\""), text, pad);
 
@@ -670,7 +756,7 @@ GNUMERIC_MAKE_COMMAND (CmdInsDelRowCol, cmd_ins_del_row_col);
 static gboolean
 cmd_ins_del_row_col_undo (GnumericCommand *cmd, WorkbookControl *wbc)
 {
-	CmdInsDelRowCol *me = CMD_INS_DEL_ROW_COL(cmd);
+	CmdInsDelRowCol *me = CMD_INS_DEL_ROW_COL (cmd);
 	int index;
 	GSList *tmp = NULL;
 	gboolean trouble;
@@ -734,7 +820,7 @@ cmd_ins_del_row_col_undo (GnumericCommand *cmd, WorkbookControl *wbc)
 static gboolean
 cmd_ins_del_row_col_redo (GnumericCommand *cmd, WorkbookControl *wbc)
 {
-	CmdInsDelRowCol *me = CMD_INS_DEL_ROW_COL(cmd);
+	CmdInsDelRowCol *me = CMD_INS_DEL_ROW_COL (cmd);
 	Range r;
 	gboolean trouble;
 	int first, last;
@@ -785,7 +871,7 @@ cmd_ins_del_row_col_redo (GnumericCommand *cmd, WorkbookControl *wbc)
 static void
 cmd_ins_del_row_col_destroy (GtkObject *cmd)
 {
-	CmdInsDelRowCol *me = CMD_INS_DEL_ROW_COL(cmd);
+	CmdInsDelRowCol *me = CMD_INS_DEL_ROW_COL (cmd);
 
 	if (me->sizes) {
 		g_free (me->sizes);
@@ -825,6 +911,8 @@ cmd_ins_del_row_col (WorkbookControl *wbc,
 	me->sizes = NULL;
 	me->contents = NULL;
 
+	me->parent.size = 1;  /* FIXME?  */
+
 	me->parent.cmd_descriptor = descriptor;
 
 	/* Register the command object */
@@ -838,7 +926,7 @@ cmd_insert_cols (WorkbookControl *wbc,
 	char *mesg = g_strdup_printf ((count > 1)
 				      ? _("Inserting %d columns before %s")
 				      : _("Inserting %d column before %s"), count,
-				      col_name(start_col));
+				      col_name (start_col));
 	return cmd_ins_del_row_col (wbc, sheet, TRUE, TRUE, mesg,
 				    start_col, count);
 }
@@ -863,11 +951,12 @@ cmd_delete_cols (WorkbookControl *wbc,
 	if (count > 1) {
 		/* col_name uses a static buffer */
 		char *temp = g_strdup_printf (_("Deleting %d columns %s:"),
-					      count, col_name(start_col));
-		mesg = g_strconcat (temp, col_name(start_col+count-1), NULL);
+					      count, col_name (start_col));
+		mesg = g_strconcat (temp, col_name (start_col+count-1), NULL);
 		g_free (temp);
 	} else
-		mesg = g_strdup_printf (_("Deleting column %s"), col_name(start_col));
+		mesg = g_strdup_printf (_("Deleting column %s"),
+					col_name (start_col));
 
 	return cmd_ins_del_row_col (wbc, sheet, TRUE, FALSE, mesg, start_col, count);
 }
@@ -905,7 +994,7 @@ GNUMERIC_MAKE_COMMAND (CmdClear, cmd_clear);
 static gboolean
 cmd_clear_undo (GnumericCommand *cmd, WorkbookControl *wbc)
 {
-	CmdClear *me = CMD_CLEAR(cmd);
+	CmdClear *me = CMD_CLEAR (cmd);
 	GSList *ranges;
 
 	g_return_val_if_fail (me != NULL, TRUE);
@@ -938,7 +1027,7 @@ cmd_clear_undo (GnumericCommand *cmd, WorkbookControl *wbc)
 static gboolean
 cmd_clear_redo (GnumericCommand *cmd, WorkbookControl *wbc)
 {
-	CmdClear *me = CMD_CLEAR(cmd);
+	CmdClear *me = CMD_CLEAR (cmd);
 	GSList *l;
 
 	g_return_val_if_fail (me != NULL, TRUE);
@@ -975,7 +1064,7 @@ cmd_clear_redo (GnumericCommand *cmd, WorkbookControl *wbc)
 static void
 cmd_clear_destroy (GtkObject *cmd)
 {
-	CmdClear *me = CMD_CLEAR(cmd);
+	CmdClear *me = CMD_CLEAR (cmd);
 
 	if (me->old_content != NULL) {
 		GSList *l;
@@ -1018,6 +1107,8 @@ cmd_clear_selection (WorkbookControl *wbc, Sheet *sheet, int clear_flags)
 	if (clear_flags & CLEAR_COMMENTS)
 		g_warning ("Deleted comments cannot be restored yet");
 
+	me->parent.size = 1;  /* FIXME?  */
+
 	/* TODO : Something more descriptive ? maybe the range name */
 	me->parent.cmd_descriptor = g_strdup (_("Clear"));
 
@@ -1181,6 +1272,8 @@ cmd_format (WorkbookControl *wbc, Sheet *sheet,
 	me->selection  = selection_get_ranges (sheet, FALSE); /* TRUE ? */
 	me->new_style  = style;
 
+	me->parent.size = 1;  /* Updated below.  */
+
 	me->old_styles = NULL;
 	for (l = me->selection; l; l = l->next) {
 		CmdFormatOldStyle *os;
@@ -1197,6 +1290,7 @@ cmd_format (WorkbookControl *wbc, Sheet *sheet,
 		os->styles = sheet_get_styles_in_range (sheet, &range);
 		os->pos = range.start;
 
+		me->parent.size += g_list_length (os->styles);
 		me->old_styles = g_slist_append (me->old_styles, os);
 	}
 
@@ -1279,6 +1373,8 @@ cmd_rename_sheet (WorkbookControl *wbc, const char *old_name, const char *new_na
 	me->old_name = g_strdup (old_name);
 	me->new_name = g_strdup (new_name);
 
+	me->parent.size = 1;
+
 	me->parent.cmd_descriptor =
 	    g_strdup_printf (_("Rename sheet '%s' '%s'"), old_name, new_name);
 
@@ -1420,11 +1516,13 @@ cmd_set_date_time (WorkbookControl *wbc,
 	me->is_date = is_date;
 	me->contents = NULL;
 
+	me->parent.size = 1;
+
 	me->parent.cmd_descriptor =
 	    g_strdup_printf (is_date
 			     ? _("Setting current date in %s")
 			     : _("Setting current time in %s"),
-			     cell_coord_name(pos->col, pos->row));
+			     cell_coord_name (pos->col, pos->row));
 
 	/* Register the command object */
 	return command_push_undo (wbc, obj);
@@ -1479,6 +1577,9 @@ cmd_resize_row_col_redo (GnumericCommand *cmd, WorkbookControl *wbc)
 
 	me->saved_sizes = col_row_set_sizes (me->sheet, me->is_cols,
 					     me->selection, me->new_size);
+	if (me->parent.size == 1)
+		me->parent.size += (g_slist_length (me->saved_sizes) +
+				    g_list_length (me->selection));
 
 	sheet_set_dirty (me->sheet, TRUE);
 	sheet_update (me->sheet);
@@ -1519,6 +1620,8 @@ cmd_resize_row_col (WorkbookControl *wbc, Sheet *sheet,
 	me->saved_sizes = NULL;
 	me->new_size = new_size;
 
+	me->parent.size = 1;  /* Changed in initial redo.  */
+
 	me->parent.cmd_descriptor = is_cols
 	    ? g_strdup (_("Setting width of columns"))
 	    : g_strdup (_("Setting height of rows"));
@@ -1588,6 +1691,7 @@ cmd_sort_redo (GnumericCommand *cmd, WorkbookControl *wbc)
 
 	if (!me->perm) {
 		me->perm = sort_contents (wbc, me->data);
+		me->parent.size += 2 * sort_data_length (me->data);
 	} else {
 		sort_position (wbc, me->data, me->perm);
 	}
@@ -1614,8 +1718,10 @@ cmd_sort (WorkbookControl *wbc, SortData *data)
 	me->perm = NULL;
 	me->inv = NULL;
 
+	me->parent.size = 1;  /* Changed in initial redo.  */
+
 	me->parent.cmd_descriptor =
-		g_strdup_printf (_("Sorting %s"), range_name(me->data->range));
+		g_strdup_printf (_("Sorting %s"), range_name (me->data->range));
 
 	/* Register the command object */
 	return command_push_undo (wbc, obj);
@@ -1695,6 +1801,8 @@ cmd_hide_selection_rows_cols (WorkbookControl *wbc, Sheet *sheet,
 	me->visible = visible;
 	me->elements = col_row_get_visiblity_toggle (sheet, is_cols, visible);
 
+	me->parent.size = 1 + g_slist_length (me->elements);
+
 	me->parent.cmd_descriptor = g_strdup (is_cols
 		? (visible ? _("Unhide columns") : _("Hide columns"))
 		: (visible ? _("Unhide rows") : _("Hide rows")));
@@ -1729,7 +1837,7 @@ typedef struct
 static gboolean
 cmd_paste_cut_undo (GnumericCommand *cmd, WorkbookControl *wbc)
 {
-	CmdPasteCut *me = CMD_PASTE_CUT(cmd);
+	CmdPasteCut *me = CMD_PASTE_CUT (cmd);
 	ExprRelocateInfo reverse;
 	GSList *tmp = NULL;
 
@@ -1786,7 +1894,7 @@ cmd_paste_cut_undo (GnumericCommand *cmd, WorkbookControl *wbc)
 static gboolean
 cmd_paste_cut_redo (GnumericCommand *cmd, WorkbookControl *wbc)
 {
-	CmdPasteCut *me = CMD_PASTE_CUT(cmd);
+	CmdPasteCut *me = CMD_PASTE_CUT (cmd);
 	Range  tmp, valid_range;
 	GList *frag;
 
@@ -1840,10 +1948,11 @@ cmd_paste_cut_redo (GnumericCommand *cmd, WorkbookControl *wbc)
 
 	return FALSE;
 }
+
 static void
 cmd_paste_cut_destroy (GtkObject *cmd)
 {
-	CmdPasteCut *me = CMD_PASTE_CUT(cmd);
+	CmdPasteCut *me = CMD_PASTE_CUT (cmd);
 
 	while (me->paste_content) {
 		PasteContent *pc = me->paste_content->data;
@@ -1879,16 +1988,18 @@ cmd_paste_cut (WorkbookControl *wbc, ExprRelocateInfo const *info,
 	me->reloc_storage  = NULL;
 	me->move_selection = move_selection;
 
+	me->parent.size = 1;  /* FIXME?  */
+
 	me->parent.cmd_descriptor = descriptor;
 
-	/* NOTE : if the destination workbook is different from the source workbook
-	 * should we have undo elements in both menus ??  It seems poor form to
-	 * hit undo in 1 window and effect another ...
+	/* NOTE : if the destination workbook is different from the source
+	 * workbook should we have undo elements in both menus ??  It seems
+	 * poor form to hit undo in 1 window and effect another...
 	 *
-	 * Maybe queue it as 2 different commands, as a clear in one book and
-	 * a paste  in the other.    This is not symetric though.  What happens to the
-	 * cells in the original sheet that now reference the cells in the other.
-	 * When do they reset to the original ?
+	 * Maybe queue it as two different commands, as a clear in one book
+	 * and a paste in the other.  This is not symmetric though.  What
+	 * happens to the cells in the original sheet that now reference the
+	 * cells in the other?  When do they reset to the original?
 	 *
 	 * Probably when the clear in the original is undone.
 	 */
@@ -1916,7 +2027,7 @@ GNUMERIC_MAKE_COMMAND (CmdPasteCopy, cmd_paste_copy);
 static gboolean
 cmd_paste_copy_undo (GnumericCommand *cmd, WorkbookControl *wbc)
 {
-	CmdPasteCopy *me = CMD_PASTE_COPY(cmd);
+	CmdPasteCopy *me = CMD_PASTE_COPY (cmd);
 	CellRegion *content;
 
 	g_return_val_if_fail (me != NULL, TRUE);
@@ -1961,7 +2072,7 @@ cmd_paste_copy_redo (GnumericCommand *cmd, WorkbookControl *wbc)
 static void
 cmd_paste_copy_destroy (GtkObject *cmd)
 {
-	CmdPasteCopy *me = CMD_PASTE_COPY(cmd);
+	CmdPasteCopy *me = CMD_PASTE_COPY (cmd);
 
 	if (me->content) {
 		if (me->has_been_through_cycle)
@@ -2007,7 +2118,10 @@ cmd_paste_copy (WorkbookControl *wbc,
 		}
 	}
 
-	me->parent.cmd_descriptor = g_strdup_printf (_("Pasting into %s"), range_name(&pt->range));
+	me->parent.size = 1;  /* FIXME?  */
+
+	me->parent.cmd_descriptor = g_strdup_printf (_("Pasting into %s"),
+						     range_name (&pt->range));
 
 	/* Register the command object */
 	return command_push_undo (wbc, obj);
@@ -2032,7 +2146,7 @@ GNUMERIC_MAKE_COMMAND (CmdAutofill, cmd_autofill);
 static gboolean
 cmd_autofill_undo (GnumericCommand *cmd, WorkbookControl *wbc)
 {
-	CmdAutofill *me = CMD_AUTOFILL(cmd);
+	CmdAutofill *me = CMD_AUTOFILL (cmd);
 	gboolean res;
 
 	g_return_val_if_fail (wbc != NULL, TRUE);
@@ -2065,12 +2179,16 @@ static gboolean
 cmd_autofill_redo (GnumericCommand *cmd, WorkbookControl *wbc)
 {
 	GList *deps;
-	CmdAutofill *me = CMD_AUTOFILL(cmd);
+	CmdAutofill *me = CMD_AUTOFILL (cmd);
 
 	g_return_val_if_fail (me != NULL, TRUE);
 	g_return_val_if_fail (me->content == NULL, TRUE);
 
 	me->content = clipboard_copy_range (me->dst.sheet, &me->dst.range);
+	if (me->parent.size == 1)
+		me->parent.size += (g_list_length (me->content->list) +
+				    g_list_length (me->content->styles) +
+				    1);
 	sheet_autofill (me->dst.sheet,
 			me->base_col, me->base_row, me->w, me->h,
 			me->end_col, me->end_row);
@@ -2098,7 +2216,7 @@ cmd_autofill_redo (GnumericCommand *cmd, WorkbookControl *wbc)
 static void
 cmd_autofill_destroy (GtkObject *cmd)
 {
-	CmdAutofill *me = CMD_AUTOFILL(cmd);
+	CmdAutofill *me = CMD_AUTOFILL (cmd);
 
 	if (me->content) {
 		clipboard_release (me->content);
@@ -2130,7 +2248,7 @@ cmd_autofill (WorkbookControl *wbc, Sheet *sheet,
 	me->dst.paste_flags = PASTE_CONTENT | PASTE_FORMATS;
 
 	/* FIXME : We can copy less than this */
-	range_init (&me->dst.range,  base_col, base_row, end_col, end_row);
+	range_init (&me->dst.range, base_col, base_row, end_col, end_row);
 	me->base_col = base_col;
 	me->base_row = base_row,
 	me->w = w;
@@ -2138,6 +2256,8 @@ cmd_autofill (WorkbookControl *wbc, Sheet *sheet,
 	me->end_col = end_col;
 	me->end_row = end_row;
 
+	me->parent.size = 1;  /* Changed in initial redo.  */
+
 	me->parent.cmd_descriptor = g_strdup (_("Autofill"));
 
 	/* Register the command object */
@@ -2294,6 +2414,8 @@ cmd_autoformat (WorkbookControl *wbc, Sheet *sheet, FormatTemplate *ft)
 		me->old_styles = g_slist_append (me->old_styles, os);
 	}
 
+	me->parent.size = 1;  /* FIXME?  */
+
 	me->parent.cmd_descriptor = g_strdup (_("Autoformat"));
 
 	/* Register the command object */
