@@ -1319,17 +1319,26 @@ expr_tree_as_string (ExprTree const *tree, ParsePos const *pp)
 	return do_expr_tree_to_string (tree, pp, 0);
 }
 
-enum CellRefRelocate {
+typedef enum {
 	CELLREF_NO_RELOCATE,
 	CELLREF_RELOCATE_ERR,
-	CELLREF_RELOCATE_COL,
-	CELLREF_RELOCATE_ROW,
-	CELLREF_RELOCATE_BOTH,
-};
+	CELLREF_RELOCATE,
 
-static enum CellRefRelocate
-cellref_relocate (CellRef *ref,
-		  ExprRelocateInfo const *rinfo)
+	/* Both ends of the range must be treated as if they are inside the range */
+	CELLREF_RELOCATE_FORCE_TO_IN,
+	CELLREF_RELOCATE_FORCE_FROM_IN,
+} CellRefRelocate;
+
+/*
+ * FIXME :
+ * C3 : =sum(a$1:b$2)
+ * Cut B2:C3
+ * Paste to the right or diagonal.
+ * range changes when it should not.
+ */
+static CellRefRelocate
+cellref_relocate (CellRef *ref, ExprRelocateInfo const *rinfo,
+		  gboolean force_to_inside, gboolean force_from_inside)
 {
 	/* For row or column refs
 	 * Ref	From	To
@@ -1359,12 +1368,14 @@ cellref_relocate (CellRef *ref,
 	/* Inside is based on the current location of the reference.
 	 * Hence we need to use the ORIGIN_sheet rather than the target.
 	 */
-	gboolean const to_inside =
-		(rinfo->origin_sheet == ref_sheet) &&
-		range_contains (&rinfo->origin, col, row);
-	gboolean const from_inside =
-		(rinfo->origin_sheet == rinfo->pos.sheet) &&
-		range_contains (&rinfo->origin, rinfo->pos.eval.col, rinfo->pos.eval.row);
+	gboolean const to_inside = force_to_inside ||
+		((rinfo->origin_sheet == ref_sheet) &&
+		range_contains (&rinfo->origin, col, row));
+	gboolean const from_inside = force_from_inside ||
+		((rinfo->origin_sheet == rinfo->pos.sheet) &&
+		range_contains (&rinfo->origin, rinfo->pos.eval.col, rinfo->pos.eval.row));
+
+	/* fprintf (stderr, "%s\n", cellref_name (ref, &rinfo->pos, FALSE)); */
 
 	/* All references should be valid initially.  We assume that later. */
 	if (col < 0 || col >= SHEET_MAX_COLS ||
@@ -1414,17 +1425,38 @@ cellref_relocate (CellRef *ref,
 		ref->sheet = ref_sheet;
 		ref->col = col;
 		ref->row = row;
-		return CELLREF_RELOCATE_BOTH;
+		return CELLREF_RELOCATE;
 	} else if (ref->col != col) {
 		ref->col = col;
 		if (ref->row != row) {
 			ref->row = row;
-			return CELLREF_RELOCATE_BOTH;
+			return CELLREF_RELOCATE;
 		}
-		return CELLREF_RELOCATE_COL;
+		/* FIXME : We should only do this if the start ? end ?
+		 * col is included in the translation region (figure this out
+		 * in relation to abs/rel references)
+		 * Using offset == 0 would relocates too much.  If you cut B2
+		 * and paste it into B3 the source region A1:B2 will resize to
+		 * A1:B3 even though it should not.  This is correct for
+		 * insert/delete row/col but not when dealing with cut & paste.
+		 * To work around the problem I added a kludge to only do it if
+		 * the target range is an entire row/col.  This gives the
+		 * desired behavior most of the time.  However, it is probably
+		 * not absolutely correct.
+		 */
+		if (rinfo->row_offset == 0 &&
+		    rinfo->origin.start.row == 0 && rinfo->origin.end.row >= SHEET_MAX_ROWS-1)
+			return from_inside ? CELLREF_RELOCATE_FORCE_FROM_IN
+					   : CELLREF_RELOCATE_FORCE_TO_IN;
+		return CELLREF_RELOCATE;
 	} else if (ref->row != row) {
 		ref->row = row;
-		return CELLREF_RELOCATE_ROW;
+		/* FIXME : As above */
+		if (rinfo->col_offset == 0 &&
+		    rinfo->origin.start.col == 0 && rinfo->origin.end.col >= SHEET_MAX_COLS-1)
+			return from_inside ? CELLREF_RELOCATE_FORCE_FROM_IN
+					   : CELLREF_RELOCATE_FORCE_TO_IN;
+		return CELLREF_RELOCATE;
 	}
 
 	return CELLREF_NO_RELOCATE;
@@ -1443,50 +1475,23 @@ cellrange_relocate (const Value *v,
 	CellRef ref_b = v->v_range.cell.b;
 	int needs_reloc = 0;
 
-	switch (cellref_relocate (&ref_a, rinfo)) {
+	switch (cellref_relocate (&ref_a, rinfo, FALSE, FALSE)) {
 	case CELLREF_NO_RELOCATE :
 		break;
 	case CELLREF_RELOCATE_ERR :
 		return expr_tree_new_constant (value_new_error (NULL, gnumeric_err_REF));
-	case CELLREF_RELOCATE_COL :
-		/* FIXME : We should only do this if the start ? end ?
-		 * col is included in the translation region (figure this out
-		 * in relation to abs/rel references)
-		 * The current code relocates too much.  If you cut B2 and
-		 * paste it into B3 the source region A1:B2 will resize to
-		 * A1:B3 even though it should not.
-		 * This is correct for insert/delete row/col but not when dealing
-		 * with cut & paste.
-		 */
-		if (rinfo->row_offset == 0)
-			needs_reloc = 2;
-		break;
-	case CELLREF_RELOCATE_ROW :
-		/* FIXME : */
-		if (rinfo->col_offset == 0)
-			needs_reloc = 2;
-		break;
-	case CELLREF_RELOCATE_BOTH :
-		needs_reloc++;
+	case CELLREF_RELOCATE :			needs_reloc++; break;
+	case CELLREF_RELOCATE_FORCE_TO_IN :	needs_reloc += 0x10;  break;
+	case CELLREF_RELOCATE_FORCE_FROM_IN :	needs_reloc += 0x100; break;
 	}
-	switch (cellref_relocate (&ref_b, rinfo)) {
+	switch (cellref_relocate (&ref_b, rinfo, FALSE, FALSE)) {
 	case CELLREF_NO_RELOCATE :
 		break;
 	case CELLREF_RELOCATE_ERR :
 		return expr_tree_new_constant (value_new_error (NULL, gnumeric_err_REF));
-	case CELLREF_RELOCATE_COL :
-		/* FIXME : */
-		if (rinfo->row_offset == 0) {
-			needs_reloc = 2;
-		}
-		break;
-	case CELLREF_RELOCATE_ROW :
-		/* FIXME : */
-		if (rinfo->col_offset == 0)
-			needs_reloc = 2;
-		break;
-	case CELLREF_RELOCATE_BOTH :
-		needs_reloc++;
+	case CELLREF_RELOCATE :			needs_reloc++; break;
+	case CELLREF_RELOCATE_FORCE_TO_IN :	needs_reloc += 0x20;  break;
+	case CELLREF_RELOCATE_FORCE_FROM_IN :	needs_reloc += 0x200; break;
 	}
 
 	/* Only relocate if both ends of the range need relocation */
@@ -1500,6 +1505,20 @@ cellrange_relocate (const Value *v,
 		if (sheet_b == NULL)
 			sheet_b = rinfo->pos.sheet;
 
+#if 0
+		/* Force only happens when inserting row/col
+		 * we want to deform the region
+		 */
+		switch (needs_reloc) {
+		case 2 : break;
+		case 0x10  : cellref_relocate (&ref_b, rinfo, TRUE, FALSE); break;
+		case 0x20  : cellref_relocate (&ref_a, rinfo, TRUE, FALSE); break;
+		case 0x100 : cellref_relocate (&ref_b, rinfo, FALSE, TRUE); break;
+		case 0x200 : cellref_relocate (&ref_a, rinfo, FALSE, TRUE); break;
+		default : g_warning ("Unexpected relocation type 0x%x", needs_reloc);
+		};
+#endif
+
 		/* Dont allow creation of 3D references */
 		if (sheet_a == sheet_b)
 			res = value_new_cellrange (&ref_a, &ref_b,
@@ -1628,14 +1647,14 @@ expr_rewrite (ExprTree        const *expr,
 		} else {
 			CellRef res = expr->var.ref; /* Copy */
 
-			switch (cellref_relocate (&res, &rwinfo->u.relocate)) {
+			switch (cellref_relocate (&res, &rwinfo->u.relocate, FALSE, FALSE)) {
 			case CELLREF_NO_RELOCATE :
 				return NULL;
 			case CELLREF_RELOCATE_ERR :
 				return expr_tree_new_constant (value_new_error (NULL, gnumeric_err_REF));
-			case CELLREF_RELOCATE_COL :
-			case CELLREF_RELOCATE_ROW :
-			case CELLREF_RELOCATE_BOTH :
+			case CELLREF_RELOCATE :
+			case CELLREF_RELOCATE_FORCE_TO_IN :
+			case CELLREF_RELOCATE_FORCE_FROM_IN :
 				return expr_tree_new_var (&res);
 			}
 		}
