@@ -48,7 +48,8 @@ gnumeric_sys_data_dir (const char *subdir)
 {
 	extern char *gnumeric_data_dir;
 
-	return g_strconcat (gnumeric_data_dir, subdir, "/", NULL);
+	return g_strconcat (gnumeric_data_dir, G_DIR_SEPARATOR_S,
+			    subdir, G_DIR_SEPARATOR_S, NULL);
 }
 
 char *
@@ -56,7 +57,8 @@ gnumeric_sys_lib_dir (const char *subdir)
 {
 	extern char *gnumeric_lib_dir;
 
-	return g_strconcat (gnumeric_lib_dir, subdir, "/", NULL);
+	return g_strconcat (gnumeric_lib_dir, G_DIR_SEPARATOR_S,
+			    subdir, G_DIR_SEPARATOR_S, NULL);
 }
 
 #define GLADE_SUFFIX	"glade"
@@ -77,12 +79,15 @@ gnumeric_sys_plugin_dir (void)
 char *
 gnumeric_usr_dir (const char *subdir)
 {
-	const char *home_dir = getenv ("HOME");
+	const char *home_dir = g_get_home_dir ();
 
-	if (home_dir != NULL)
-		return g_strconcat (
-			home_dir, "/.gnumeric/" GNUMERIC_VERSION "/",
-			subdir, "/", NULL);
+	if (home_dir != NULL) {
+		gboolean has_slash = (home_dir[strlen (home_dir) - 1] == G_DIR_SEPARATOR);
+		return g_strconcat (home_dir, (has_slash ? "" : G_DIR_SEPARATOR_S),
+				    ".gnumeric" G_DIR_SEPARATOR_S GNUMERIC_VERSION G_DIR_SEPARATOR_S,
+				    subdir, G_DIR_SEPARATOR_S,
+				    NULL);
+	}
 	return NULL;
 }
 
