@@ -30,6 +30,22 @@ static void   item_bar_marshal      (GtkObject *,
 typedef void (*ItemBarSignal1) (GtkObject *, gint arg1, gpointer data);
 typedef void (*ItemBarSignal2) (GtkObject *, gint arg1, gint arg2, gpointer data);
 
+#if 0
+#ifndef __GNUC__
+#define __FUNCTION__ __FILE__
+#endif
+#define gnome_canvas_item_grab(a,b,c,d)	do {		\
+	fprintf (stderr, "%s %d: grab BAR %p\n",	\
+		 __FUNCTION__, __LINE__, a);		\
+	gnome_canvas_item_grab (a, b, c,d);		\
+} while (0)
+#define gnome_canvas_item_ungrab(a,b) do {		\
+	fprintf (stderr, "%s %d: ungrab BAR %p\n",	\
+		 __FUNCTION__, __LINE__, a);		\
+	gnome_canvas_item_ungrab (a, b);		\
+} while (0)
+#endif
+
 /* The signals we emit */
 enum {
 	SELECTION_CHANGED,
@@ -88,7 +104,7 @@ void
 item_bar_fonts_init (ItemBar *item_bar)
 {
 	double const zoom_factor =
-		item_bar->sheet_view->sheet->last_zoom_factor_used;
+		item_bar->scg->sheet->last_zoom_factor_used;
 	double const res  = application_dpi_to_pixels ();
 	StyleFont * const normal_font =
 		style_font_new_simple (DEFAULT_FONT, DEFAULT_SIZE,
@@ -218,12 +234,14 @@ bar_draw_cell (ItemBar const * const item_bar,
 static void
 item_bar_draw (GnomeCanvasItem *item, GdkDrawable *drawable, int x, int y, int width, int height)
 {
-	ItemBar const * const item_bar = ITEM_BAR (item);
-	Sheet   const * const sheet = item_bar->sheet_view->sheet;
-	GnumericSheet const * const gsheet = GNUMERIC_SHEET (item_bar->sheet_view->canvas);
+	ItemBar const         *item_bar = ITEM_BAR (item);
+	SheetControlGUI const *scg = item_bar->scg;
+	Sheet const           *sheet = scg->sheet;
+	GnumericSheet const   *gsheet = GNUMERIC_SHEET (scg->canvas);
 	GtkWidget *canvas = GTK_WIDGET (GNOME_CANVAS_ITEM (item)->canvas);
 	int pixels;
 	GdkRectangle rect;
+	gboolean has_object = scg->new_object != NULL || scg->current_object != NULL;
 
 	if (item_bar->orientation == GTK_ORIENTATION_VERTICAL) {
 		/* Include a 1 pixel buffer.
@@ -266,7 +284,8 @@ item_bar_draw (GnomeCanvasItem *item, GdkDrawable *drawable, int x, int y, int w
 					rect.y = total - pixels;
 					rect.height = pixels;
 					bar_draw_cell (item_bar, drawable,
-						       sheet_row_selection_type (sheet, element),
+						       has_object ? COL_ROW_NO_SELECTION
+						       : sheet_row_selection_type (sheet, element),
 						       str, &rect);
 				}
 			}
@@ -304,7 +323,8 @@ item_bar_draw (GnomeCanvasItem *item, GdkDrawable *drawable, int x, int y, int w
 					rect.x = total - pixels;
 					rect.width = pixels;
 					bar_draw_cell (item_bar, drawable,
-						       sheet_col_selection_type (sheet, element),
+						       has_object ? COL_ROW_NO_SELECTION
+						       : sheet_col_selection_type (sheet, element),
 						       col_name (element), &rect);
 				}
 			}
@@ -336,7 +356,7 @@ is_pointer_on_division (ItemBar *item_bar, int pos, int *the_total, int *the_ele
 	int i, total;
 
 	total = 0;
-	sheet = item_bar->sheet_view->sheet;
+	sheet = item_bar->scg->sheet;
 
 	for (i = item_bar->first_element; total < pos; i++){
 		if (item_bar->orientation == GTK_ORIENTATION_VERTICAL){
@@ -388,7 +408,7 @@ set_cursor (ItemBar *item_bar, int pos)
 static void
 item_bar_start_resize (ItemBar *bar)
 {
-	Sheet const * const sheet = bar->sheet_view->sheet;
+	Sheet const * const sheet = bar->scg->sheet;
 #if 0
 	/*
 	 * handle the zoom from the item-grid canvas, the resolution scaling is
@@ -398,7 +418,7 @@ item_bar_start_resize (ItemBar *bar)
 							 GTK_ORIENTATION_VERTICAL);
 #endif
 	double const zoom = sheet->last_zoom_factor_used; /* * res / 72.; */
-	GnumericSheet const * const gsheet = GNUMERIC_SHEET (bar->sheet_view->canvas);
+	GnumericSheet const * const gsheet = GNUMERIC_SHEET (bar->scg->canvas);
 	GnomeCanvas const * const canvas = GNOME_CANVAS (gsheet);
 	GnomeCanvasGroup * const group = GNOME_CANVAS_GROUP (canvas->root);
 	GnomeCanvasPoints * const points =
@@ -451,7 +471,7 @@ get_element_from_pixel (ItemBar *item_bar, int pos)
 	int i, total;
 
 	total = 0;
-	sheet = item_bar->sheet_view->sheet;
+	sheet = item_bar->scg->sheet;
 	for (i = item_bar->first_element; total < pos; i++){
 		if (item_bar->orientation == GTK_ORIENTATION_VERTICAL){
 			if (i >= SHEET_MAX_ROWS)
@@ -476,15 +496,16 @@ static void
 colrow_tip_setlabel (ItemBar *item_bar, gboolean const is_vertical, int size_pixels)
 {
 	if (item_bar->tip) {
-		char buffer [20 + sizeof (long) * 4];
+		char *buffer;
 		double const scale = 72. / application_display_dpi_get (is_vertical);
 		if (is_vertical)
-			snprintf (buffer, sizeof (buffer), _("Height: %.2f pts (%d pixels)"),
+			buffer = g_strdup_printf (_("Height: %.2f pts (%d pixels)"),
 				  scale*size_pixels, size_pixels);
 		else
-			snprintf (buffer, sizeof (buffer), _("Width: %.2f pts (%d pixels)"),
+			buffer = g_strdup_printf (_("Width: %.2f pts (%d pixels)"),
 				  scale*size_pixels, size_pixels);
 		gtk_label_set_text (GTK_LABEL (item_bar->tip), buffer);
+		g_free(buffer);
 	}
 }
 
@@ -516,7 +537,7 @@ item_bar_end_resize (ItemBar *item_bar, int new_size)
 }
 
 static gboolean
-cb_extend_selection (SheetControlGUI *sheet_view, int col, int row, gpointer user_data)
+cb_extend_selection (SheetControlGUI *scg, int col, int row, gpointer user_data)
 {
 	ItemBar * const item_bar = user_data;
 	gboolean const is_vertical = (item_bar->orientation == GTK_ORIENTATION_VERTICAL);
@@ -532,8 +553,8 @@ item_bar_event (GnomeCanvasItem *item, GdkEvent *e)
 	ColRowInfo *cri;
 	GnomeCanvas * const canvas = item->canvas;
 	ItemBar * const item_bar = ITEM_BAR (item);
-	Sheet   * const sheet = item_bar->sheet_view->sheet;
-	GnumericSheet * const gsheet = GNUMERIC_SHEET (item_bar->sheet_view->canvas);
+	Sheet   * const sheet = item_bar->scg->sheet;
+	GnumericSheet * const gsheet = GNUMERIC_SHEET (item_bar->scg->canvas);
 	gboolean const is_vertical = (item_bar->orientation == GTK_ORIENTATION_VERTICAL);
 #if 0
 	/*
@@ -633,11 +654,11 @@ item_bar_event (GnomeCanvasItem *item, GdkEvent *e)
 						dx = x - width - left;
 				}
 
-				sheet_view_start_sliding (item_bar->sheet_view,
+				sheet_view_start_sliding (item_bar->scg,
 							  &cb_extend_selection, item_bar,
 							  col, row, dx, dy);
 			} else
-				sheet_view_stop_sliding (item_bar->sheet_view);
+				sheet_view_stop_sliding (item_bar->scg);
 
 			set_cursor (item_bar, pos);
 		} else
@@ -649,6 +670,8 @@ item_bar_event (GnomeCanvasItem *item, GdkEvent *e)
 		if (e->button.button > 3)
 			return FALSE;
 
+		scg_mode_edit (item_bar->scg);
+
 		if (is_vertical)
 			pos = e->button.y;
 		else
@@ -673,8 +696,8 @@ item_bar_event (GnomeCanvasItem *item, GdkEvent *e)
 						 item_bar_signals [SELECTION_CHANGED],
 						 element, e->button.state | GDK_BUTTON1_MASK);
 
-			item_grid_popup_menu (item_bar->sheet_view, &e->button,
-					      !is_vertical, is_vertical);
+			scg_context_menu (item_bar->scg, &e->button,
+					  !is_vertical, is_vertical);
 		} else if (cri) {
 			/*
 			 * Record the important bits.
@@ -694,7 +717,6 @@ item_bar_event (GnomeCanvasItem *item, GdkEvent *e)
 				gtk_widget_show_all (gtk_widget_get_toplevel (item_bar->tip));
 			}
 		} else {
-
 			item_bar->start_selection = element;
 			gnome_canvas_item_grab (item,
 						GDK_POINTER_MOTION_MASK |
@@ -713,10 +735,8 @@ item_bar_event (GnomeCanvasItem *item, GdkEvent *e)
 		if (e->button.button > 3)
 			return FALSE;
 
-		if (e->button.button == 3)
-			break;
-
-		item_bar_end_resize (item_bar, -1);
+		if (e->button.button != 3)
+			item_bar_end_resize (item_bar, -1);
 		break;
 	}
 
@@ -728,7 +748,7 @@ item_bar_event (GnomeCanvasItem *item, GdkEvent *e)
 		if (e->button.button > 3)
 			return FALSE;
 
-		sheet_view_stop_sliding (item_bar->sheet_view);
+		sheet_view_stop_sliding (item_bar->scg);
 
 		if (item_bar->start_selection >= 0) {
 			needs_ungrab = TRUE;
@@ -793,7 +813,7 @@ item_bar_set_arg (GtkObject *o, GtkArg *arg, guint arg_id)
 
 	switch (arg_id){
 	case ARG_SHEET_CONTROL_GUI:
-		item_bar->sheet_view = GTK_VALUE_POINTER (*arg);
+		item_bar->scg = GTK_VALUE_POINTER (*arg);
 		break;
 	case ARG_ORIENTATION:
 		item_bar->orientation = GTK_VALUE_INT (*arg);
