@@ -22,6 +22,22 @@
 
 static GnomeCanvasItem *item_cursor_parent_class;
 
+#if 0
+#ifndef __GNUC__
+#define __FUNCTION__ __FILE__
+#endif
+#define gnome_canvas_item_grab(a,b,c,d)	do {		\
+	fprintf (stderr, "%s %d: grab CURSOR %p\n",	\
+		 __FUNCTION__, __LINE__, a);	       	\
+	gnome_canvas_item_grab (a, b, c,d);		\
+} while (0)
+#define gnome_canvas_item_ungrab(a,b) do {		\
+	fprintf (stderr, "%s %d: ungrab CURSOR %p\n",	\
+		 __FUNCTION__, __LINE__, a);		\
+	gnome_canvas_item_ungrab (a, b);		\
+} while (0)
+#endif
+
 #define AUTO_HANDLE_SPACE	4
 #define CLIP_SAFETY_MARGIN      (AUTO_HANDLE_SPACE + 5)
 #define IS_LITTLE_SQUARE(item,x,y) \
@@ -32,9 +48,10 @@ static GnomeCanvasItem *item_cursor_parent_class;
 /* The argument we take */
 enum {
 	ARG_0,
-	ARG_SHEETVIEW,		/* The SheetControlGUI * argument */
+	ARG_SHEET_CONTROL_GUI,	/* The SheetControlGUI * argument */
 	ARG_ITEM_GRID,		/* The ItemGrid * argument */
 	ARG_STYLE,              /* The style type */
+	ARG_BUTTON,		/* The button used to drag this cursor around */
 	ARG_COLOR,              /* The optional color */
 };
 
@@ -151,7 +168,7 @@ item_cursor_update (GnomeCanvasItem *item, double *affine, ArtSVP *clip_path, in
 {
 	ItemCursor    *item_cursor = ITEM_CURSOR (item);
 	GnumericSheet *gsheet = GNUMERIC_SHEET (item->canvas);
-	Sheet         *sheet = item_cursor->sheet_view->sheet;
+	Sheet         *sheet = item_cursor->scg->sheet;
 
 	int x, y, w, h, extra;
 
@@ -568,12 +585,10 @@ item_cursor_selection_event (GnomeCanvasItem *item, GdkEvent *event)
 		gnome_canvas_w2c (
 			canvas, event->motion.x, event->motion.y, &x, &y);
 
-		if (!ic->prepared_to_drag) {
+		if (ic->drag_button < 0) {
 			item_cursor_set_cursor (canvas, ic, x, y);
 			return TRUE;
 		}
-		ic->prepared_to_drag = FALSE;
-		gnome_canvas_item_ungrab (item, event->button.time);
 
 		/*
 		 * determine which part of the cursor was clicked:
@@ -587,11 +602,15 @@ item_cursor_selection_event (GnomeCanvasItem *item, GdkEvent *event)
 		new_item = gnome_canvas_item_new (
 			GNOME_CANVAS_GROUP (canvas->root),
 			item_cursor_get_type (),
-			"ItemCursor::SheetControlGUI", ic->sheet_view,
+			"ItemCursor::SheetControlGUI", ic->scg,
 			"ItemCursor::Grid",  ic->item_grid,
 			"ItemCursor::Style", style,
+			"ItemCursor::Button", ic->drag_button,
 			NULL);
 
+		ic->drag_button = -1;
+		gnome_canvas_item_ungrab (item, event->button.time);
+
 		if (style == ITEM_CURSOR_AUTOFILL)
 			item_cursor_setup_auto_fill (
 				ITEM_CURSOR (new_item), ic, x, y);
@@ -656,13 +675,13 @@ item_cursor_selection_event (GnomeCanvasItem *item, GdkEvent *event)
 	}
 
 	case GDK_2BUTTON_PRESS: {
-		Sheet *sheet = ic->sheet_view->sheet;
+		Sheet *sheet = ic->scg->sheet;
 		int final_col = ic->pos.end.col;
 		int final_row = ic->pos.end.col;
 
-		g_return_val_if_fail (ic->prepared_to_drag, TRUE);
+		g_return_val_if_fail (ic->drag_button >= 0, TRUE);
 
-		ic->prepared_to_drag = FALSE;
+		ic->drag_button = -1;
 
 		/*
 		 * We flush after the ungrab, to have the ungrab take
@@ -673,7 +692,7 @@ item_cursor_selection_event (GnomeCanvasItem *item, GdkEvent *event)
 		gnome_canvas_item_ungrab (item, event->button.time);
 		gdk_flush ();
 
-		workbook_finish_editing (ic->sheet_view->wbcg, TRUE);
+		workbook_finish_editing (ic->scg->wbcg, TRUE);
 
 		if (sheet_is_region_empty (sheet, &ic->pos))
 			return TRUE;
@@ -715,7 +734,7 @@ item_cursor_selection_event (GnomeCanvasItem *item, GdkEvent *event)
 		}
 
 		/* fill the row/column */
-		cmd_autofill (WORKBOOK_CONTROL (ic->sheet_view->wbcg), sheet,
+		cmd_autofill (WORKBOOK_CONTROL (ic->scg->wbcg), sheet,
 			      ic->pos.start.col,    ic->pos.start.row,
 			      ic->pos.end.col - ic->pos.start.col + 1,
 			      ic->pos.end.row - ic->pos.start.row + 1,
@@ -725,8 +744,8 @@ item_cursor_selection_event (GnomeCanvasItem *item, GdkEvent *event)
 	}
 
 	case GDK_BUTTON_PRESS:
-		g_return_val_if_fail (!ic->prepared_to_drag, TRUE);
-		ic->prepared_to_drag = TRUE;
+		g_return_val_if_fail (ic->drag_button < 0, TRUE);
+		ic->drag_button = event->button.button;
 
 		/* prepare to create fill or drag cursors, but dont until we
 		 * move.  If we did create them here there would be problems
@@ -745,8 +764,8 @@ item_cursor_selection_event (GnomeCanvasItem *item, GdkEvent *event)
 
 	case GDK_BUTTON_RELEASE:
 		/* Double clicks may have already released the drag prep */
-		if (ic->prepared_to_drag) {
-			ic->prepared_to_drag = FALSE;
+		if (ic->drag_button >= 0) {
+			ic->drag_button = -1;
 			gnome_canvas_item_ungrab (item, event->button.time);
 			gdk_flush ();
 		}
@@ -763,12 +782,12 @@ item_cursor_target_region_ok (ItemCursor *ic)
 	int v;
 	GtkWidget	*message;
 	GnomeCanvasItem *gci = GNOME_CANVAS_ITEM (ic);
-	SheetControlGUI	*sheet_view = ic->sheet_view;
+	SheetControlGUI	*scg = ic->scg;
 
 	g_return_val_if_fail (gci != NULL, FALSE);
 	g_return_val_if_fail (gci->canvas != NULL, FALSE);
 
-	if (sheet_is_region_empty_or_selected (sheet_view->sheet, &ic->pos))
+	if (sheet_is_region_empty_or_selected (scg->sheet, &ic->pos))
 		return TRUE;
 
 	message = gnome_message_box_new (
@@ -779,7 +798,7 @@ item_cursor_target_region_ok (ItemCursor *ic)
 		GNOME_STOCK_BUTTON_YES,
 		GNOME_STOCK_BUTTON_NO,
 		NULL);
-	v = gnumeric_dialog_run (sheet_view->wbcg, GNOME_DIALOG (message));
+	v = gnumeric_dialog_run (scg->wbcg, GNOME_DIALOG (message));
 
 	if (v == 0)
 		return TRUE;
@@ -811,37 +830,37 @@ item_cursor_do_action (ItemCursor *item_cursor, ActionType action, guint32 time)
 
 	g_return_if_fail (item_cursor != NULL);
 
-	sheet = item_cursor->sheet_view->sheet;
+	sheet = item_cursor->scg->sheet;
 
 	switch (action) {
 	case ACTION_COPY_CELLS:
-		if (!sheet_selection_copy (WORKBOOK_CONTROL (item_cursor->sheet_view->wbcg), sheet))
+		if (!sheet_selection_copy (WORKBOOK_CONTROL (item_cursor->scg->wbcg), sheet))
 			break;
-		cmd_paste (WORKBOOK_CONTROL (item_cursor->sheet_view->wbcg),
+		cmd_paste (WORKBOOK_CONTROL (item_cursor->scg->wbcg),
 			   paste_target_init (&pt, sheet, &item_cursor->pos, PASTE_ALL_TYPES),
 			   time);
 		break;
 
 	case ACTION_MOVE_CELLS:
-		if (!sheet_selection_cut (WORKBOOK_CONTROL (item_cursor->sheet_view->wbcg), sheet))
+		if (!sheet_selection_cut (WORKBOOK_CONTROL (item_cursor->scg->wbcg), sheet))
 			break;
-		cmd_paste (WORKBOOK_CONTROL (item_cursor->sheet_view->wbcg),
+		cmd_paste (WORKBOOK_CONTROL (item_cursor->scg->wbcg),
 			   paste_target_init (&pt, sheet, &item_cursor->pos, PASTE_ALL_TYPES),
 			   time);
 		break;
 
 	case ACTION_COPY_FORMATS:
-		if (!sheet_selection_copy (WORKBOOK_CONTROL (item_cursor->sheet_view->wbcg), sheet))
+		if (!sheet_selection_copy (WORKBOOK_CONTROL (item_cursor->scg->wbcg), sheet))
 			break;
-		cmd_paste (WORKBOOK_CONTROL (item_cursor->sheet_view->wbcg),
+		cmd_paste (WORKBOOK_CONTROL (item_cursor->scg->wbcg),
 			   paste_target_init (&pt, sheet, &item_cursor->pos, PASTE_FORMATS),
 			   time);
 		break;
 
 	case ACTION_COPY_VALUES:
-		if (!sheet_selection_copy (WORKBOOK_CONTROL (item_cursor->sheet_view->wbcg), sheet))
+		if (!sheet_selection_copy (WORKBOOK_CONTROL (item_cursor->scg->wbcg), sheet))
 			break;
-		cmd_paste (WORKBOOK_CONTROL (item_cursor->sheet_view->wbcg),
+		cmd_paste (WORKBOOK_CONTROL (item_cursor->scg->wbcg),
 			   paste_target_init (&pt, sheet, &item_cursor->pos, PASTE_AS_VALUES),
 			   time);
 		break;
@@ -916,7 +935,7 @@ static void
 item_cursor_do_drop (ItemCursor *ic, GdkEventButton *event)
 {
 	/* Only do the operation if something moved */
-	Sheet const *sheet = ic->sheet_view->sheet;
+	Sheet const *sheet = ic->scg->sheet;
 	Range const *target = selection_first_range (sheet, FALSE);
 
 	if (target == NULL || range_equal (target, &ic->pos)) {
@@ -1011,7 +1030,7 @@ item_cursor_tip_setlabel (ItemCursor *item_cursor)
 #endif
 
 static gboolean
-cb_move_cursor (SheetControlGUI *sheet_view, int col, int row, gpointer user_data)
+cb_move_cursor (SheetControlGUI *scg, int col, int row, gpointer user_data)
 {
 	ItemCursor *item_cursor = user_data;
 	int const w = (item_cursor->pos.end.col - item_cursor->pos.start.col);
@@ -1077,37 +1096,41 @@ item_cursor_handle_motion (ItemCursor *item_cursor, GdkEvent *event,
 		else if (y >= top + height)
 			dy = y - height - top;
 
-		if (sheet_view_start_sliding (item_cursor->sheet_view,
+		if (sheet_view_start_sliding (item_cursor->scg,
 					      slide_handler, item_cursor,
 					      col, row, dx, dy))
 			return;
 	}
-	sheet_view_stop_sliding (item_cursor->sheet_view);
+	sheet_view_stop_sliding (item_cursor->scg);
 
-	(*slide_handler) (item_cursor->sheet_view, col, row, item_cursor);
+	(*slide_handler) (item_cursor->scg, col, row, item_cursor);
 }
 
 static gint
 item_cursor_drag_event (GnomeCanvasItem *item, GdkEvent *event)
 {
-	ItemCursor *item_cursor = ITEM_CURSOR (item);
+	ItemCursor *ic = ITEM_CURSOR (item);
 
 	switch (event->type){
 	case GDK_BUTTON_RELEASE:
-		sheet_view_stop_sliding (item_cursor->sheet_view);
-
-		gnome_canvas_item_ungrab (item, event->button.time);
-		item_cursor_do_drop (item_cursor, (GdkEventButton *) event);
+		/* Note : see comment below, and bug 30507 */
+		if (event->button.button == ic->drag_button) {
+			sheet_view_stop_sliding (ic->scg);
+			gnome_canvas_item_ungrab (item, event->button.time);
+			item_cursor_do_drop (ic, (GdkEventButton *) event);
+		}
 		return TRUE;
 
 	case GDK_BUTTON_PRESS:
-		/* We actually never get this event: this kind of
-		 * cursor is created and grabbed
+		/* This kind of cursor is created and grabbed.  Then destroyed
+		 * when the button is released.  If we are seeing a press it
+		 * means that someone has pressed another button WHILE THE
+		 * FIRST IS STILL DOWN.  Ignore ths event.
 		 */
 		return TRUE;
 
 	case GDK_MOTION_NOTIFY:
-		item_cursor_handle_motion (item_cursor, event, &cb_move_cursor);
+		item_cursor_handle_motion (ic, event, &cb_move_cursor);
 		return TRUE;
 
 	default:
@@ -1116,7 +1139,7 @@ item_cursor_drag_event (GnomeCanvasItem *item, GdkEvent *event)
 }
 
 static gboolean
-cb_autofill_scroll (SheetControlGUI *sheet_view, int col, int row, gpointer user_data)
+cb_autofill_scroll (SheetControlGUI *scg, int col, int row, gpointer user_data)
 {
 	ItemCursor *item_cursor = user_data;
 	int bottom = item_cursor->base_row + item_cursor->base_rows;
@@ -1153,8 +1176,8 @@ item_cursor_autofill_event (GnomeCanvasItem *item, GdkEvent *event)
 	switch (event->type){
 
 	case GDK_BUTTON_RELEASE: {
-		Sheet *sheet = item_cursor->sheet_view->sheet;
-		sheet_view_stop_sliding (item_cursor->sheet_view);
+		Sheet *sheet = item_cursor->scg->sheet;
+		sheet_view_stop_sliding (item_cursor->scg);
 
 		/*
 		 * We flush after the ungrab, to have the ungrab take
@@ -1165,8 +1188,8 @@ item_cursor_autofill_event (GnomeCanvasItem *item, GdkEvent *event)
 		gnome_canvas_item_ungrab (item, event->button.time);
 		gdk_flush ();
 
-		workbook_finish_editing (item_cursor->sheet_view->wbcg, TRUE);
-		cmd_autofill (WORKBOOK_CONTROL (item_cursor->sheet_view->wbcg), sheet,
+		workbook_finish_editing (item_cursor->scg->wbcg, TRUE);
+		cmd_autofill (WORKBOOK_CONTROL (item_cursor->scg->wbcg), sheet,
 			      item_cursor->base_col,    item_cursor->base_row,
 			      item_cursor->base_cols+1, item_cursor->base_rows+1,
 			      item_cursor->pos.end.col, item_cursor->pos.end.row);
@@ -1246,7 +1269,7 @@ item_cursor_init (ItemCursor *item_cursor)
 
 	item_cursor->visible = TRUE;
 	item_cursor->auto_fill_handle_at_top = FALSE;
-	item_cursor->prepared_to_drag = FALSE;
+	item_cursor->drag_button = -1;
 }
 
 static void
@@ -1259,8 +1282,8 @@ item_cursor_set_arg (GtkObject *o, GtkArg *arg, guint arg_id)
 	item_cursor = ITEM_CURSOR (o);
 
 	switch (arg_id){
-	case ARG_SHEETVIEW:
-		item_cursor->sheet_view = GTK_VALUE_POINTER (*arg);
+	case ARG_SHEET_CONTROL_GUI:
+		item_cursor->scg = GTK_VALUE_POINTER (*arg);
 		break;
 	case ARG_ITEM_GRID:
 		item_cursor->item_grid = GTK_VALUE_POINTER (*arg);
@@ -1268,7 +1291,9 @@ item_cursor_set_arg (GtkObject *o, GtkArg *arg, guint arg_id)
 	case ARG_STYLE:
 		item_cursor->style = GTK_VALUE_INT (*arg);
 		break;
-
+	case ARG_BUTTON :
+		item_cursor->drag_button = GTK_VALUE_INT (*arg);
+		break;
 	case ARG_COLOR: {
 		GdkColor color;
 		char *color_name;
@@ -1297,11 +1322,13 @@ item_cursor_class_init (ItemCursorClass *item_cursor_class)
 	item_class = (GnomeCanvasItemClass *) item_cursor_class;
 
 	gtk_object_add_arg_type ("ItemCursor::SheetControlGUI", GTK_TYPE_POINTER,
-				 GTK_ARG_WRITABLE, ARG_SHEETVIEW);
+				 GTK_ARG_WRITABLE, ARG_SHEET_CONTROL_GUI);
 	gtk_object_add_arg_type ("ItemCursor::Grid", GTK_TYPE_POINTER,
 				 GTK_ARG_WRITABLE, ARG_ITEM_GRID);
 	gtk_object_add_arg_type ("ItemCursor::Style", GTK_TYPE_INT,
 				 GTK_ARG_WRITABLE, ARG_STYLE);
+	gtk_object_add_arg_type ("ItemCursor::Button", GTK_TYPE_INT,
+				 GTK_ARG_WRITABLE, ARG_BUTTON);
 	gtk_object_add_arg_type ("ItemCursor::Color", GTK_TYPE_STRING,
 				 GTK_ARG_WRITABLE, ARG_COLOR);
 
