@@ -19,9 +19,9 @@ typedef enum {
 struct _ItemCursor {
 	GnomeCanvasItem canvas_item;
 
-	SheetControlGUI    *sheet_view;
-	ItemGrid *item_grid;	/* A copy of our "parent" grid */
-	Range     pos;
+	SheetControlGUI *scg;
+	ItemGrid	*item_grid;	/* A copy of our "parent" grid */
+	Range     	 pos;
 
 	/* Offset of dragging cell from top left of pos */
 	int col_delta, row_delta;
@@ -55,7 +55,7 @@ struct _ItemCursor {
 	int      use_color:1;
 	/* Location of auto fill handle */
 	int      auto_fill_handle_at_top:1;
-	int      prepared_to_drag:1;
+	int      drag_button;
 
 	GdkPixmap *stipple;
 	GdkColor  color;
