@@ -20,6 +20,7 @@
 #include <sys/types.h>
 #include <regex.h>
 #include <errno.h>
+#include <locale.h>
 #include "number-match.h"
 #include "formats.h"
 #include "dates.h"
@@ -43,7 +44,7 @@ create_option_list (const char *const *list)
 	const char *const *p;
 	char *res;
 
-	for (p = list; *p; p++){
+	for (p = list; *p; p++) {
 		const char *v = _(*p);
 
 		if (*v == '*')
@@ -53,16 +54,16 @@ create_option_list (const char *const *list)
 	len += 5;
 
 	res = g_malloc (len);
-	res [0] = '(';
-	res [1] = 0;
-	for (p = list; *p; p++){
+	res[0] = '(';
+	res[1] = 0;
+	for (p = list; *p; p++) {
 		const char *v = _(*p);
 
 		if (*v == '*')
 			v++;
 
 		strcat (res, v);
-		if (*(p+1))
+		if (*(p + 1))
 		    strcat (res, "|");
 	}
 	strcat (res, ")");
@@ -106,8 +107,8 @@ format_create_regexp (const unsigned char *format, GByteArray **dest)
 	regexp = g_string_new ("");
 	match_types = g_byte_array_new ();
 
-	for (; *format; format++){
-		switch (*format){
+	for (; *format; format++) {
+		switch (*format) {
 		case '_':
 			if (format[1]) {
 				g_string_append (regexp, "[ ]?");
@@ -126,12 +127,12 @@ format_create_regexp (const unsigned char *format, GByteArray **dest)
 			break;
 
 		case 'P': case 'p':
-			if (tolower (*(format+1)) == 'm')
+			if (tolower (*(format + 1)) == 'm')
 				format++;
 			break;
 
 		case '\\':
-			if (*(format+1)){
+			if (*(format + 1)) {
 				format++;
 				g_string_append_c (regexp, *format);
 			}
@@ -220,7 +221,7 @@ format_create_regexp (const unsigned char *format, GByteArray **dest)
 		case 'h':
 		case 'H':
 			hour_seen = TRUE;
-			if (tolower (*(format+1)) == 'h')
+			if (tolower (*(format + 1)) == 'h')
 				format++;
 
 			g_string_append (regexp, "([0-9][0-9]?)");
@@ -229,16 +230,16 @@ format_create_regexp (const unsigned char *format, GByteArray **dest)
 
 		case 'M':
 		case 'm':
-			if (hour_seen){
-				if (tolower (*(format+1)) == 'm')
+			if (hour_seen) {
+				if (tolower (*(format + 1)) == 'm')
 					format++;
 				g_string_append (regexp, "([0-9][0-9]?)");
 				append_type (MATCH_MINUTE);
 				hour_seen = FALSE;
 			} else {
-				if (tolower (*(format+1)) == 'm'){
-					if (tolower (*(format+2)) == 'm'){
-						if (tolower (*(format+3)) == 'm'){
+				if (tolower (*(format + 1)) == 'm') {
+					if (tolower (*(format + 2)) == 'm') {
+						if (tolower (*(format + 3)) == 'm') {
 							char *l;
 
 							l = create_option_list (month_long);
@@ -277,11 +278,11 @@ format_create_regexp (const unsigned char *format, GByteArray **dest)
 			 */
 			{
 				int l = match_types->len;
-				if (l > 0 && match_types->data [l-1] == MATCH_MONTH_NUMBER)
-					match_types->data [l-1] = MATCH_MINUTE;
+				if (l > 0 && match_types->data[l - 1] == MATCH_MONTH_NUMBER)
+					match_types->data[l - 1] = MATCH_MINUTE;
 			}
 
-			if (tolower (*(format+1) == 's'))
+			if (tolower (*(format + 1) == 's'))
 				format++;
 			g_string_append (regexp, "([0-9][0-9]?)");
 			append_type (MATCH_SECOND);
@@ -289,9 +290,9 @@ format_create_regexp (const unsigned char *format, GByteArray **dest)
 
 		case 'D':
 		case 'd':
-			if (tolower (*(format+1) == 'd')){
-				if (tolower (*(format+2) == 'd')){
-					if (tolower (*(format+3) == 'd')){
+			if (tolower (*(format + 1) == 'd')) {
+				if (tolower (*(format + 2) == 'd')) {
+					if (tolower (*(format + 3) == 'd')) {
 						char *l;
 
 						l = create_option_list (day_long);
@@ -321,9 +322,9 @@ format_create_regexp (const unsigned char *format, GByteArray **dest)
 
 		case 'Y':
 		case 'y':
-			if (tolower (*(format+1) == 'y')){
-				if (tolower (*(format+2) == 'y')){
-					if (tolower (*(format+3) == 'y')){
+			if (tolower (*(format + 1) == 'y')) {
+				if (tolower (*(format + 2) == 'y')) {
+					if (tolower (*(format + 3) == 'y')) {
 						g_string_append (regexp, "([0-9][0-9][0-9][0-9])");
 						append_type (MATCH_YEAR_FULL);
 						format++;
@@ -347,10 +348,10 @@ format_create_regexp (const unsigned char *format, GByteArray **dest)
 			break;
 
 		case 'A': case 'a':
-			if (*(format+1) == 'm' || *(format+1) == 'M'){
-				if (*(format+2) == '/'){
-					if (*(format+3) == 'P' || *(format+3) == 'p'){
-						if (*(format+4) == 'm' || *(format+4) == 'M'){
+			if (*(format + 1) == 'm' || *(format + 1) == 'M') {
+				if (*(format + 2) == '/') {
+					if (*(format + 3) == 'P' || *(format + 3) == 'p') {
+						if (*(format + 4) == 'm' || *(format + 4) == 'M') {
 							format++;
 						}
 						format++;
@@ -365,25 +366,26 @@ format_create_regexp (const unsigned char *format, GByteArray **dest)
 
 			/* Matches a string */
 		case '"': {
-			const unsigned char *p;
-			char *buf;
+			const unsigned char *p, *q;
 
-			for (p = format+1; *p && *p != '"'; p++)
-				;
+			for (p = format + 1; *p && *p != '"'; p++)
+				; /* Nothing */
 
 			if (*p != '"')
 				goto error;
 
-			if (format+1 != p){
-				buf = g_malloc (p - (format+1) + 1);
-				strncpy (buf, format+1, p - (format+1));
-				buf [p - (format+1)] = 0;
-
-				/* FIXME: we should escape buf */
-				g_string_append (regexp, buf);
-
-				g_free (buf);
+			for (q = format + 1; q < p; q++) {
+				switch (*q) {
+				case '\\': case '$': case '^': case '.':
+				case '+': case '*': case '?': case '|':
+				case '[': case ']':
+					g_string_append_c (regexp, '\\');
+					/* Fall through.  */
+				default:
+					g_string_append_c (regexp, *q);					
+				}
 			}
+
 			format = p;
 			break;
 		}
@@ -408,61 +410,87 @@ format_create_regexp (const unsigned char *format, GByteArray **dest)
 static void
 print_regex_error (int ret)
 {
-	switch (ret){
+	switch (ret) {
 	case REG_BADBR:
-		printf ("There was an invalid `\\{...\\}' construct in the regular\n"
-			"expression.  A valid `\\{...\\}' construct must contain either a\n"
-			"single number, or two numbers in increasing order separated by a\n"
-			"comma.\n");
+		fprintf (stderr,
+			 "There was an invalid `\\{...\\}' construct in the regular\n"
+			 "expression.  A valid `\\{...\\}' construct must contain either a\n"
+			 "single number, or two numbers in increasing order separated by a\n"
+			 "comma.\n");
 		break;
 
 	case REG_BADPAT:
-		printf ("There was a syntax error in the regular expression.\n");
+		fprintf (stderr,
+			 "There was a syntax error in the regular expression.\n");
 		break;
 
 	case REG_BADRPT:
-		printf ("A repetition operator such as `?' or `*' appeared in a bad\n"
-			"position (with no preceding subexpression to act on).\n");
+		fprintf (stderr,
+			 "A repetition operator such as `?' or `*' appeared in a bad\n"
+			 "position (with no preceding subexpression to act on).\n");
 		break;
 
 	case REG_ECOLLATE:
-		printf ("The regular expression referred to an invalid collating element\n"
-			"(one not defined in the current locale for string collation).\n");
+		fprintf (stderr,
+			 "The regular expression referred to an invalid collating element\n"
+			 "(one not defined in the current locale for string collation).\n");
 		break;
 
 	case REG_ECTYPE:
-		printf ("The regular expression referred to an invalid character class name.\n");
+		fprintf (stderr,
+			 "The regular expression referred to an invalid character class name.\n");
 		break;
 
 	case REG_EESCAPE:
-		printf ("The regular expression ended with `\\'.\n");
+		fprintf (stderr,
+			 "The regular expression ended with `\\'.\n");
 		break;
 
 	case REG_ESUBREG:
-		printf ("There was an invalid number in the `\\DIGIT' construct.\n");
+		fprintf (stderr,
+			 "There was an invalid number in the `\\DIGIT' construct.\n");
 		break;
 
 	case REG_EBRACK:
-		printf ("There were unbalanced square brackets in the regular expression.\n");
+		fprintf (stderr,
+			 "There were unbalanced square brackets in the regular expression.\n");
 		break;
 
 	case REG_EPAREN:
-		printf ("An extended regular expression had unbalanced parentheses, or a\n"
-			"basic regular expression had unbalanced `\\(' and `\\)'.\n");
+		fprintf (stderr,
+			 "An extended regular expression had unbalanced parentheses, or a\n"
+			 "basic regular expression had unbalanced `\\(' and `\\)'.\n");
 		break;
 
 	case REG_EBRACE:
-		printf ("The regular expression had unbalanced `\\{' and `\\}'.\n");
+		fprintf (stderr,
+			 "The regular expression had unbalanced `\\{' and `\\}'.\n");
 		break;
 
+#ifdef REG_EBOL
+	case REG_EBOL:
+		fprintf (stderr, "Found ^ not at the beginning.\n");
+		break;
+#endif
+
+#ifdef REG_EEOL
+	case REG_EEOL:
+		fprintf (stderr, "Found $ not at the end.\n");
+		break;
+#endif
+
 	case REG_ERANGE:
-		printf ("One of the endpoints in a range expression was invalid.\n");
+		fprintf (stderr,
+			 "One of the endpoints in a range expression was invalid.\n");
 		break;
 
 	case REG_ESPACE:
-		printf ("`regcomp' ran out of memory.\n");
+		fprintf (stderr,
+			 "`regcomp' ran out of memory.\n");
 		break;
 
+	default:
+		fprintf (stderr, "regexp error %d\n", ret);
 	}
 }
 
@@ -475,7 +503,7 @@ typedef struct {
 
 static GList *format_match_list = NULL;
 
-int
+gboolean
 format_match_define (const char *format)
 {
 	format_parse_t *fp;
@@ -489,9 +517,10 @@ format_match_define (const char *format)
 		return FALSE;
 
 	ret = regcomp (&r, regexp, REG_EXTENDED | REG_ICASE);
-	if (ret != 0){
+	if (ret != 0) {
 		g_warning ("expression %s\nproduced:%s\n", format, regexp);
 		print_regex_error (ret);
+		g_free (regexp);
 		return FALSE;
 	}
 
@@ -530,10 +559,10 @@ static char const *
 gnumeric_error_init (int const indx, char const * str)
 {
 	g_return_val_if_fail (indx >= 0, str);
-	g_return_val_if_fail (indx < sizeof(gnumeric_error_data)/sizeof(struct gnumeric_error_info), str);
+	g_return_val_if_fail (indx < sizeof (gnumeric_error_data) / sizeof (struct gnumeric_error_info), str);
 
 	gnumeric_error_data[indx].str = str;
-	gnumeric_error_data[indx].len = strlen(str);
+	gnumeric_error_data[indx].len = strlen (str);
 	return str;
 }
 
@@ -548,7 +577,7 @@ gnumeric_error_init (int const indx, char const * str)
 static Value *
 value_is_error (char const * const str)
 {
-	int i = sizeof(gnumeric_error_data)/sizeof(struct gnumeric_error_info);
+	int i = sizeof (gnumeric_error_data) / sizeof (struct gnumeric_error_info);
 
 	g_return_val_if_fail (str != NULL, NULL);
 
@@ -570,10 +599,10 @@ format_match_init (void)
 
 	currency_date_format_init ();
 
-	for (i = 0; cell_formats [i]; i++){
-		char const * const * p = cell_formats [i];
+	for (i = 0; cell_formats[i]; i++) {
+		char const * const * p = cell_formats[i];
 
-		for (; *p; p++){
+		for (; *p; p++) {
 			if (strcmp (*p, "General") == 0)
 				continue;
 			format_match_define (*p);
@@ -596,7 +625,7 @@ format_match_finish (void)
 {
 	GList *l;
 
-	for (l = format_match_list; l; l = l->next){
+	for (l = format_match_list; l; l = l->next) {
 		format_parse_t *fp = l->data;
 
 		style_format_unref (fp->format);
@@ -622,11 +651,11 @@ table_lookup (const char *str, const char *const *table)
 	const char *const *p = table;
 	int i = 0;
 
-	for (p = table; *p; p++, i++){
+	for (p = table; *p; p++, i++) {
 		const char *v  = *p;
 		const char *iv = _(*p);
 
-		if (*v == '*'){
+		if (*v == '*') {
 			v++;
 			iv++;
 		}
@@ -654,8 +683,8 @@ extract_text (const char *str, const regmatch_t *mp)
 	char *p;
 
 	p = g_malloc (mp->rm_eo - mp->rm_so + 1);
-	strncpy (p, &str [mp->rm_so], mp->rm_eo - mp->rm_so);
-	p [mp->rm_eo - mp->rm_so] = 0;
+	strncpy (p, &str[mp->rm_so], mp->rm_eo - mp->rm_so);
+	p[mp->rm_eo - mp->rm_so] = 0;
 
 	return p;
 }
@@ -689,17 +718,17 @@ compute_value (const char *s, const regmatch_t *mp,
 	hours = minutes = -1;
 	seconds = -1.;
 
-	for (i = 0; i < len; i++){
+	for (i = 0; i < len; i++) {
 		MatchType type = *(data++);
 		char *str;
 
-		str = extract_text (s, &mp [idx]);
+		str = extract_text (s, &mp[idx]);
 
 
 #ifdef DEBUG_NUMBER_MATCH
 		printf ("Item %d is a %d\n", idx, type);
 #endif
-		switch (type){
+		switch (type) {
 		case MATCH_MONTH_FULL:
 			month = table_lookup (str, month_long);
 			if (month == -1)
@@ -736,9 +765,10 @@ compute_value (const char *s, const regmatch_t *mp,
 				char *ptr = str;
 
 				number = 0.;
+				/* FIXME: this loop is bogus.  */
 				do {
-				    number *= 1000.;
-				    number += strtod (ptr, &ptr);
+					number *= 1000.;
+					number += strtol (ptr, &ptr, 10);
 				} while (*(ptr++) == thousands_sep);
 				is_number = TRUE;
 			}
@@ -805,7 +835,7 @@ compute_value (const char *s, const regmatch_t *mp,
 		g_free (str);
 	}
 
-	if (is_number){
+	if (is_number) {
 		if (percentify)
 			number *= 0.01;
 		*v = number;
@@ -816,8 +846,8 @@ compute_value (const char *s, const regmatch_t *mp,
 		time_t t = time (NULL);
 		GDate *date;
 		struct tm *tm = localtime (&t);
-		if (year == -1){
-			if (year_short != -1){
+		if (year == -1) {
+			if (year_short != -1) {
 				/* Window of -75 thru +24 years. */
 				/* (TODO: See what current
 				 * version of MS Excel uses.) */
@@ -827,9 +857,9 @@ compute_value (const char *s, const regmatch_t *mp,
 					= tm->tm_year + 1900 - 75;
 				int earliest_cc = earliest_ccyy / 100;
 
-				g_return_val_if_fail(year_short >= 0 &&
-						     year_short <= 99,
-						     FALSE);
+				g_return_val_if_fail (year_short >= 0 &&
+						      year_short <= 99,
+						      FALSE);
 				year = earliest_cc * 100 + year_short;
 				/*
 				 * Our first guess at year has the same
@@ -991,7 +1021,7 @@ format_match (const char *text, StyleFormat **format)
 {
 	Value   *v;
 	GList *l;
-	regmatch_t mp [NM+1];
+	regmatch_t mp[NM + 1];
 
 	if (format)
 		*format = NULL;
@@ -1001,7 +1031,7 @@ format_match (const char *text, StyleFormat **format)
 
 	/* If it begins with a '\'' it is a string */
 	if (text[0] == '\'')
-		return value_new_string (text+1);
+		return value_new_string (text + 1);
 
 	/* TODO : We should check the format associated with the region first,
 	 *        but we're not passing that information in yet
@@ -1013,7 +1043,7 @@ format_match (const char *text, StyleFormat **format)
 		return v;
 
 	/* Fall back to checking the set of canned formats */
-	for (l = format_match_list; l; l = l->next){
+	for (l = format_match_list; l; l = l->next) {
 		float_t result;
 		gboolean b;
 		format_parse_t *fp = l->data;
@@ -1027,14 +1057,14 @@ format_match (const char *text, StyleFormat **format)
 		{
 			int i;
 			printf ("matches expression: %s %s\n", fp->format_str, fp->regexp_str);
-			for (i = 0; i < NM; i++){
+			for (i = 0; i < NM; i++) {
 				char *p;
 
-				if (mp [i].rm_so == -1)
+				if (mp[i].rm_so == -1)
 					break;
 
-				p = extract_text (text, &mp [i]);
-				printf ("%d %d->%s\n", mp [i].rm_so, mp [i].rm_eo, p);
+				p = extract_text (text, &mp[i]);
+				printf ("%d %d->%s\n", mp[i].rm_so, mp[i].rm_eo, p);
 			}
 		}
 #endif
