@@ -7,22 +7,22 @@
  * Names
  */
 const char *col_name                 (int col);
-int         col_from_name            (const char *cell_str);
 
 char        *cellref_name            (CellRef const *cell_ref,
-				      ParsePos const *pp);
+				      ParsePos const *pp, gboolean no_sheetname);
 gboolean     cellref_get             (CellRef *out, const char *in,
-				      int parse_col, int parse_row);
+				      CellPos const *pos);
 gboolean     cellref_a1_get          (CellRef *out, const char *in,
-				      int parse_col, int parse_row);
+				      CellPos const *pos);
 gboolean     cellref_r1c1_get        (CellRef *out, const char *in,
-				      int parse_col, int parse_row);
+				      CellPos const *pos);
 
 const char *cell_coord_name	     (int const col, int const row);
 const char *cell_pos_name	     (CellPos const *pos);
 const char *cell_name                (Cell const *cell);
 
 /* Various parsing routines */
+int         parse_col_name           (const char *cell_str, const char **endptr);
 gboolean    parse_cell_name          (const char *cell_str, int *col, int *row,
 				      gboolean strict, int *chars_read);
 gboolean    parse_cell_name_or_range (const char *cell_str, int *col, int *row,
@@ -49,6 +49,7 @@ typedef enum {
 ParseErr    gnumeric_expr_parser   (const char *expr,
 				    const ParsePos *pp,
 				    gboolean use_excel_range_conventions,
+				    gboolean create_place_holder_for_unknown_func,
 				    StyleFormat **desired_format,
 				    ExprTree **result);
 
