@@ -194,7 +194,7 @@ unregister_allocation (const void *data)
 		g_ptr_array_index (deallocate_stack, pos + 1) =
 			g_ptr_array_index (deallocate_stack, pos + 3);
 
-		g_ptr_array_set_size (deallocate_stack, pos);
+		g_ptr_array_set_size (deallocate_stack, pos + 2);
 		return;
 	}
 
@@ -431,11 +431,11 @@ static const short yyrhs[] = {    34,
 
 #if YYDEBUG != 0
 static const short yyrline[] = { 0,
-   354,   359,   362,   363,   364,   365,   366,   367,   368,   369,
-   370,   371,   372,   373,   374,   375,   376,   377,   378,   380,
-   381,   382,   384,   390,   407,   421,   422,   425,   433,   457,
-   458,   461,   465,   470,   481,   496,   501,   507,   517,   520,
-   521,   524,   529,   538,   547,   550,   555
+   354,   359,   368,   369,   370,   371,   372,   373,   374,   375,
+   376,   377,   378,   379,   380,   381,   382,   383,   384,   386,
+   387,   388,   390,   396,   413,   427,   428,   431,   439,   463,
+   464,   467,   471,   476,   487,   502,   507,   513,   523,   526,
+   527,   530,   535,   544,   553,   556,   561
 };
 #endif
 
@@ -1093,90 +1093,96 @@ case 1:
     break;}
 case 2:
 #line 359 "parser.y"
-{ parser_error = PARSE_ERR_SYNTAX; ;
+{
+		parser_error = PARSE_ERR_SYNTAX;
+		if (*parser_result) {
+			expr_tree_unref (*parser_result);
+			*parser_result = NULL;
+		}
+	;
     break;}
 case 3:
-#line 362 "parser.y"
+#line 368 "parser.y"
 { yyval.tree = yyvsp[0].tree; ;
     break;}
 case 4:
-#line 363 "parser.y"
+#line 369 "parser.y"
 { yyval.tree = yyvsp[0].tree; ;
     break;}
 case 5:
-#line 364 "parser.y"
+#line 370 "parser.y"
 { yyval.tree = parse_string_as_value_or_name (yyvsp[0].tree); ;
     break;}
 case 6:
-#line 365 "parser.y"
+#line 371 "parser.y"
 { yyval.tree = yyvsp[0].tree; ;
     break;}
 case 7:
-#line 366 "parser.y"
+#line 372 "parser.y"
 { yyval.tree = build_binop (yyvsp[-2].tree, OPER_ADD,       yyvsp[0].tree); ;
     break;}
 case 8:
-#line 367 "parser.y"
+#line 373 "parser.y"
 { yyval.tree = build_binop (yyvsp[-2].tree, OPER_SUB,       yyvsp[0].tree); ;
     break;}
 case 9:
-#line 368 "parser.y"
+#line 374 "parser.y"
 { yyval.tree = build_binop (yyvsp[-2].tree, OPER_MULT,      yyvsp[0].tree); ;
     break;}
 case 10:
-#line 369 "parser.y"
+#line 375 "parser.y"
 { yyval.tree = build_binop (yyvsp[-2].tree, OPER_DIV,       yyvsp[0].tree); ;
     break;}
 case 11:
-#line 370 "parser.y"
+#line 376 "parser.y"
 { yyval.tree = build_binop (yyvsp[-2].tree, OPER_EXP,       yyvsp[0].tree); ;
     break;}
 case 12:
-#line 371 "parser.y"
+#line 377 "parser.y"
 { yyval.tree = build_binop (yyvsp[-2].tree, OPER_CONCAT,    yyvsp[0].tree); ;
     break;}
 case 13:
-#line 372 "parser.y"
+#line 378 "parser.y"
 { yyval.tree = build_binop (yyvsp[-2].tree, OPER_EQUAL,     yyvsp[0].tree); ;
     break;}
 case 14:
-#line 373 "parser.y"
+#line 379 "parser.y"
 { yyval.tree = build_binop (yyvsp[-2].tree, OPER_LT,        yyvsp[0].tree); ;
     break;}
 case 15:
-#line 374 "parser.y"
+#line 380 "parser.y"
 { yyval.tree = build_binop (yyvsp[-2].tree, OPER_GT,        yyvsp[0].tree); ;
     break;}
 case 16:
-#line 375 "parser.y"
+#line 381 "parser.y"
 { yyval.tree = build_binop (yyvsp[-2].tree, OPER_GTE,       yyvsp[0].tree); ;
     break;}
 case 17:
-#line 376 "parser.y"
+#line 382 "parser.y"
 { yyval.tree = build_binop (yyvsp[-2].tree, OPER_NOT_EQUAL, yyvsp[0].tree); ;
     break;}
 case 18:
-#line 377 "parser.y"
+#line 383 "parser.y"
 { yyval.tree = build_binop (yyvsp[-2].tree, OPER_LTE,       yyvsp[0].tree); ;
     break;}
 case 19:
-#line 378 "parser.y"
+#line 384 "parser.y"
 { yyval.tree = yyvsp[-1].tree; ;
     break;}
 case 20:
-#line 380 "parser.y"
+#line 386 "parser.y"
 { yyval.tree = build_unary_op (OPER_PERCENT, yyvsp[-1].tree); ;
     break;}
 case 21:
-#line 381 "parser.y"
+#line 387 "parser.y"
 { yyval.tree = build_unary_op (OPER_UNARY_NEG, yyvsp[0].tree); ;
     break;}
 case 22:
-#line 382 "parser.y"
+#line 388 "parser.y"
 { yyval.tree = build_unary_op (OPER_UNARY_PLUS, yyvsp[0].tree); ;
     break;}
 case 23:
-#line 384 "parser.y"
+#line 390 "parser.y"
 {
 		unregister_allocation (yyvsp[-1].list);
 		yyval.tree = build_array (yyvsp[-1].list);
@@ -1184,7 +1190,7 @@ case 23:
 	;
     break;}
 case 24:
-#line 390 "parser.y"
+#line 396 "parser.y"
 {
 		char *name = yyvsp[-3].tree->constant.value->v_str.val->str;
 		FunctionDefinition *f = func_lookup_by_name (name,
@@ -1204,7 +1210,7 @@ case 24:
 	;
     break;}
 case 25:
-#line 407 "parser.y"
+#line 413 "parser.y"
 {
 		NamedExpression *expr_name;
 		char *name = yyvsp[0].tree->constant.value->v_str.val->str;
@@ -1219,7 +1225,7 @@ case 25:
 	;
     break;}
 case 28:
-#line 425 "parser.y"
+#line 431 "parser.y"
 {
 		Sheet *sheet = sheet_lookup_by_name (parser_pos->wb, yyvsp[-1].tree->constant.value->v_str.val->str);
 		unregister_allocation (yyvsp[-1].tree); expr_tree_unref (yyvsp[-1].tree);
@@ -1229,7 +1235,7 @@ case 28:
 	;
     break;}
 case 29:
-#line 433 "parser.y"
+#line 439 "parser.y"
 {
 		/* TODO : Get rid of ParseErr and replace it with something richer.
 		 * The replace ment should include more detail as to what the error
@@ -1254,24 +1260,24 @@ case 29:
         ;
     break;}
 case 31:
-#line 458 "parser.y"
+#line 464 "parser.y"
 { yyval.sheet = NULL; ;
     break;}
 case 32:
-#line 461 "parser.y"
+#line 467 "parser.y"
 {
 	        yyval.tree = yyvsp[0].tree;
 	;
     break;}
 case 33:
-#line 465 "parser.y"
+#line 471 "parser.y"
 {
 		yyvsp[0].tree->var.ref.sheet = yyvsp[-1].sheet;
 	        yyval.tree = yyvsp[0].tree;
 	;
     break;}
 case 34:
-#line 470 "parser.y"
+#line 476 "parser.y"
 {
 		unregister_allocation (yyvsp[0].tree);
 		unregister_allocation (yyvsp[-2].tree);
@@ -1284,7 +1290,7 @@ case 34:
 	;
     break;}
 case 35:
-#line 481 "parser.y"
+#line 487 "parser.y"
 {
 		unregister_allocation (yyvsp[0].tree);
 		unregister_allocation (yyvsp[-3].tree);
@@ -1300,7 +1306,7 @@ case 35:
 	;
     break;}
 case 36:
-#line 496 "parser.y"
+#line 502 "parser.y"
 {
 		unregister_allocation (yyvsp[0].tree);
 		yyval.list = g_list_prepend (NULL, yyvsp[0].tree);
@@ -1308,7 +1314,7 @@ case 36:
         ;
     break;}
 case 37:
-#line 501 "parser.y"
+#line 507 "parser.y"
 {
 		unregister_allocation (yyvsp[0].list);
 		unregister_allocation (yyvsp[-2].tree);
@@ -1317,7 +1323,7 @@ case 37:
 	;
     break;}
 case 38:
-#line 507 "parser.y"
+#line 513 "parser.y"
 {
 		GList *tmp = yyvsp[0].list;
 		unregister_allocation (yyvsp[0].list);
@@ -1330,19 +1336,19 @@ case 38:
 	;
     break;}
 case 39:
-#line 517 "parser.y"
+#line 523 "parser.y"
 { yyval.list = NULL; ;
     break;}
 case 40:
-#line 520 "parser.y"
+#line 526 "parser.y"
 { yyval.tree = yyvsp[0].tree; ;
     break;}
 case 41:
-#line 521 "parser.y"
+#line 527 "parser.y"
 { parse_string_as_value (yyvsp[0].tree); yyval.tree = yyvsp[0].tree; ;
     break;}
 case 42:
-#line 524 "parser.y"
+#line 530 "parser.y"
 {
 		unregister_allocation (yyvsp[0].tree);
 		yyval.list = g_list_prepend (NULL, yyvsp[0].tree);
@@ -1350,7 +1356,7 @@ case 42:
         ;
     break;}
 case 43:
-#line 529 "parser.y"
+#line 535 "parser.y"
 {
 		if (parser_array_col_separator == ',') {
 			unregister_allocation (yyvsp[0].list);
@@ -1362,7 +1368,7 @@ case 43:
 	;
     break;}
 case 44:
-#line 538 "parser.y"
+#line 544 "parser.y"
 {
 		if (parser_array_col_separator == '\\') {
 			unregister_allocation (yyvsp[0].list);
@@ -1374,11 +1380,11 @@ case 44:
 	;
     break;}
 case 45:
-#line 547 "parser.y"
+#line 553 "parser.y"
 { yyval.list = NULL; ;
     break;}
 case 46:
-#line 550 "parser.y"
+#line 556 "parser.y"
 {
 		unregister_allocation (yyvsp[0].list);
 		yyval.list = g_list_prepend (NULL, yyvsp[0].list);
@@ -1386,7 +1392,7 @@ case 46:
         ;
     break;}
 case 47:
-#line 555 "parser.y"
+#line 561 "parser.y"
 {
 		unregister_allocation (yyvsp[0].list);
 		unregister_allocation (yyvsp[-2].list);
@@ -1616,7 +1622,7 @@ yyerrhandle:
     }
   return 1;
 }
-#line 562 "parser.y"
+#line 568 "parser.y"
 
 /**
  * parse_ref_or_string :
@@ -1694,27 +1700,37 @@ yylex (void)
 	if (is_number) {
 		Value *v = NULL;
 
-		if (c == parser_decimal_point) {
+		if (c == parser_decimal_point || tolower (c) == 'e') {
 			/* This is float */
 			char *end;
-			double d = strtod (start, &end);
-			if (start != end && errno != ERANGE) {
-				v = value_new_float ((float_t)d);
-				parser_expr = end;
+			double d;
+
+			errno = 0;
+			d = strtod (start, &end);
+			if (start != end) {
+				if (errno != ERANGE) {
+					v = value_new_float ((float_t)d);
+					parser_expr = end;
+				}
 			}
 		} else {
 			/* This could be a row range ref or an integer */
 			char *end;
-			long l = strtol (start, &end, 10);
-			if (start != end && errno != ERANGE) {
-				/* Check for a Row range ref (3:4 == A3:IV4) */
-				if (*end == ':' && l < SHEET_MAX_COLS) {
-				    /* TODO : adjust parser to allow returning
-				     * a range, not just a cellref
-				     */
+			long l;
+
+			errno = 0;
+			l = strtol (start, &end, 10);
+			if (start != end) {
+				if (errno != ERANGE) {
+					/* Check for a Row range ref (3:4 == A3:IV4) */
+					if (*end == ':' && l < SHEET_MAX_COLS) {
+					    /* TODO : adjust parser to allow returning
+					     * a range, not just a cellref
+					     */
+					}
+					v = value_new_int (l);
+					parser_expr = end;
 				}
-				v = value_new_int (l);
-				parser_expr = end;
 			}
 		}
 
@@ -1828,6 +1844,7 @@ gnumeric_expr_parser (const char *expr, const ParsePos *pp,
 	parser_pos  = pp;
 	parser_desired_format = desired_format;
 	parser_result = result;
+	*parser_result = NULL;
 
 	if (parser_desired_format)
 		*parser_desired_format = NULL;
@@ -1866,7 +1883,6 @@ gnumeric_expr_parser (const char *expr, const ParsePos *pp,
 	} else {
 		fprintf (stderr, "Unable to parse '%s'\n", expr);
 		deallocate_all ();
-		*parser_result = NULL;
 		if (desired_format && *desired_format) {
 			style_format_unref (*desired_format);
 			*desired_format = NULL;
