@@ -24,11 +24,12 @@ struct _RenderedValue {
 	 * Computed sizes of rendered text.
 	 * In pixels EXCLUSIVE of margins and grid lines
 	 */
-	int         width_pixel, height_pixel;
+	short         width_pixel, height_pixel;
+	gboolean      dynamic_width;
 };
 
-RenderedValue * rendered_value_new           (Cell *cell, GList *styles);
-RenderedValue * rendered_value_new_ext       (Cell *cell, MStyle *mstyle);
+RenderedValue * rendered_value_new           (Cell *cell, MStyle *mstyle,
+					      gboolean dynamic_width);
 void            rendered_value_destroy       (RenderedValue *rv);
 void            rendered_value_calc_size     (Cell const *cell);
 void            rendered_value_calc_size_ext (Cell const *cell, MStyle *mstyle);
