@@ -49,63 +49,6 @@ segments_intersect (int const s_a, int const e_a,
 	return (e_a <= e_b) ? 2 : 1;
 }
 
-static const char *
-sheet_get_selection_name (Sheet const *sheet)
-{
-	SheetSelection const *ss = sheet->selections->data;
-	static char buffer [10 + 2 * 4 * sizeof (int)];
-
-	if (range_is_singleton (&ss->user))
-		return cell_pos_name (&ss->user.start);
-	snprintf (buffer, sizeof (buffer), _("%dLx%dC"),
-		  ss->user.end.row - ss->user.start.row + 1,
-		  ss->user.end.col - ss->user.start.col + 1);
-	return buffer;
-}
-
-/**
- * sheet_selection_add_range : prepends a new range to the selection list.
- *
- * @sheet          : sheet whose selection to append to.
- * @edit_{col,row} : cell to mark as the new edit cursor.
- * @base_{col,row} : stationary corner of the newly selected range.
- * @move_{col,row} : moving corner of the newly selected range.
- *
- * Prepends a range to the selection list and set the edit cursor.
- */
-void
-sheet_selection_add_range (Sheet *sheet,
-			   int edit_col, int edit_row,
-			   int base_col, int base_row,
-			   int move_col, int move_row)
-{
-	SheetSelection *ss;
-
-	g_return_if_fail (sheet != NULL);
-	g_return_if_fail (IS_SHEET (sheet));
-
-	/* Create and prepend new selection */
-	ss = g_new0 (SheetSelection, 1);
-	ss->user.start.col = MIN (base_col, move_col);
-	ss->user.start.row = MIN (base_row, move_row);
-	ss->user.end.col   = MAX (base_col, move_col);
-	ss->user.end.row   = MAX (base_row, move_row);
-	sheet->selections = g_list_prepend (sheet->selections, ss);
-
-	/* Set the selection parameters, and redraw the old edit cursor */
-	sheet_cursor_set (sheet,
-			  edit_col, edit_row,
-			  base_col, base_row,
-			  move_col, move_row);
-
-	/* Redraw the newly added range so that it get shown as selected */
-	sheet_redraw_range (sheet, &ss->user);
-	sheet_redraw_headers (sheet, TRUE, TRUE, &ss->user);
-
-	/* Force update of the status area */
-	sheet_flag_status_update_range (sheet, NULL /* force update */);
-}
-
 /**
  * Return 1st range.
  * Return NULL if there is more than 1 and @permit_complex is FALSE
@@ -116,7 +59,6 @@ selection_first_range (Sheet const *sheet, gboolean const permit_complex)
 	SheetSelection *ss;
 	GList *l;
 
-	g_return_val_if_fail (sheet != NULL, 0);
 	g_return_val_if_fail (IS_SHEET (sheet), 0);
 
 	l = g_list_first (sheet->selections);
@@ -142,7 +84,6 @@ gboolean
 selection_is_simple (WorkbookControl *wbc, Sheet const *sheet,
 		     char const *command_name)
 {
-	g_return_val_if_fail (sheet != NULL, FALSE);
 	g_return_val_if_fail (IS_SHEET (sheet), FALSE);
 
 	if (g_list_length (sheet->selections) == 1)
@@ -154,13 +95,41 @@ selection_is_simple (WorkbookControl *wbc, Sheet const *sheet,
 	return FALSE;
 }
 
+/**
+ * sheet_selection_add_range : prepends a new range to the selection list.
+ *
+ * @sheet          : sheet whose selection to append to.
+ * @edit_{col,row} : cell to mark as the new edit cursor.
+ * @base_{col,row} : stationary corner of the newly selected range.
+ * @move_{col,row} : moving corner of the newly selected range.
+ *
+ * Prepends a range to the selection list and set the edit cursor.
+ */
+void
+sheet_selection_add_range (Sheet *sheet,
+			   int edit_col, int edit_row,
+			   int base_col, int base_row,
+			   int move_col, int move_row)
+{
+	SheetSelection *ss;
+
+	g_return_if_fail (IS_SHEET (sheet));
+
+	/* Create and prepend new selection */
+	ss = g_new0 (SheetSelection, 1);
+	sheet->selections = g_list_prepend (sheet->selections, ss);
+
+	sheet_flag_status_update_range (sheet, NULL /* force update */);
+	sheet_selection_set (sheet, edit_col, edit_row,
+			     base_col, base_row, move_col, move_row);
+}
+
 void
 sheet_selection_add (Sheet *sheet, int col, int row)
 {
 	sheet_selection_add_range (sheet, col, row, col, row, col, row);
 }
 
-
 /**
  * sheet_selection_extend_to:
  * @sheet: the sheet
@@ -173,9 +142,6 @@ sheet_selection_add (Sheet *sheet, int col, int row)
 void
 sheet_selection_extend_to (Sheet *sheet, int col, int row)
 {
-	char const *sel_descr;
-
-	g_return_if_fail (sheet != NULL);
 	g_return_if_fail (IS_SHEET (sheet));
 
 	/* If nothing was going to change dont redraw */
@@ -196,13 +162,10 @@ sheet_selection_extend_to (Sheet *sheet, int col, int row)
 	 * but this is somewhat lower level that I want to do this.
 	 */
 	sheet_update (sheet);
-	sel_descr = sheet_get_selection_name (sheet);
 	WORKBOOK_FOREACH_VIEW (sheet->workbook, view,
 	{
-		if (wb_view_cur_sheet (view) == sheet) {
-			WORKBOOK_VIEW_FOREACH_CONTROL(view, control,
-				wb_control_selection_descr_set (control, sel_descr););
-		}
+		if (wb_view_cur_sheet (view) == sheet)
+			wb_view_selection_desc (view, FALSE, NULL);
 	});
 }
 
@@ -242,7 +205,6 @@ sheet_is_all_selected (Sheet const * const sheet)
 	SheetSelection *ss;
 	GList *l;
 
-	g_return_val_if_fail (sheet != NULL, FALSE);
 	g_return_val_if_fail (IS_SHEET (sheet), FALSE);
 
 	for (l = sheet->selections; l != NULL; l = l->next){
@@ -262,9 +224,6 @@ sheet_is_cell_selected (Sheet const * const sheet, int col, int row)
 {
 	GList *list;
 
-	if (sheet->current_object != NULL || sheet->new_object != NULL)
-		return FALSE;
-
 	for (list = sheet->selections; list; list = list->next){
 		SheetSelection const *ss = list->data;
 
@@ -282,16 +241,12 @@ sheet_selection_redraw (Sheet const *sheet)
 	for (sel = sheet->selections; sel; sel = sel->next){
 		SheetSelection const *ss = sel->data;
 		Range const *r = &ss->user;
-		GList *view;
 
-		for (view = sheet->sheet_views; view; view = view->next){
-			SheetControlGUI *sheet_view = view->data;
-
-			sheet_view_redraw_cell_region (sheet_view,
+		SHEET_FOREACH_CONTROL (sheet, control,
+			sheet_view_redraw_cell_region (control,
 				r->start.col, r->start.row,
 				r->end.col, r->end.row);
-		}
-		sheet_redraw_headers (sheet, TRUE, TRUE, &ss->user);
+			sheet_view_redraw_headers (control, TRUE, TRUE, r););
 	}
 }
 
@@ -312,16 +267,34 @@ sheet_is_range_selected (Sheet const * const sheet, Range const *r)
 	return FALSE;
 }
 
+/*
+ * TRUE : If entire range is contained in the selection
+ */
+gboolean
+sheet_is_full_range_selected (Sheet const * const sheet, Range const *r)
+{
+	GList *list;
+
+	for (list = sheet->selections; list; list = list->next){
+		SheetSelection const *ss = list->data;
+
+		if (range_contained (r, &ss->user))
+			return TRUE;
+	}
+	return FALSE;
+}
+
 void
 sheet_selection_set (Sheet *sheet,
 		     int edit_col, int edit_row,
 		     int base_col, int base_row,
 		     int move_col, int move_row)
 {
+	GSList *merged, *ptr;
+	gboolean changed, reset_positions = FALSE;
 	SheetSelection *ss;
 	Range old_sel, new_sel;
 
-	g_return_if_fail (sheet != NULL);
 	g_return_if_fail (IS_SHEET (sheet));
 	g_return_if_fail (sheet->selections != NULL);
 
@@ -332,6 +305,52 @@ sheet_selection_set (Sheet *sheet,
 	new_sel.end.col = MAX(base_col, move_col);
 	new_sel.end.row = MAX(base_row, move_row);
 
+	/* expand to include any merged regions */
+looper :
+	changed = FALSE;
+	merged = sheet_region_get_merged (sheet, &new_sel);
+	for (ptr = merged ; ptr != NULL ; ptr = ptr->next) {
+		Range const *r = ptr->data;
+		if (new_sel.start.col > r->start.col) {
+			new_sel.start.col = r->start.col;
+			changed = TRUE;
+		}
+		if (new_sel.start.row > r->start.row) {
+			new_sel.start.row = r->start.row;
+			changed = TRUE;
+		}
+		if (new_sel.end.col < r->end.col) {
+			new_sel.end.col = r->end.col;
+			changed = TRUE;
+		}
+		if (new_sel.end.row < r->end.row) {
+			new_sel.end.row = r->end.row;
+			changed = TRUE;
+		}
+	}
+	g_slist_free (merged);
+	if (changed) {
+		reset_positions = TRUE;
+		goto looper;
+	}
+
+	if (reset_positions) {
+		if (base_col < move_col) {
+			base_col = new_sel.start.col;
+			move_col = new_sel.end.col;
+		} else {
+			base_col = new_sel.end.col;
+			move_col = new_sel.start.col;
+		}
+		if (base_row < move_row) {
+			base_row = new_sel.start.row;
+			move_row = new_sel.end.row;
+		} else {
+			base_row = new_sel.end.row;
+			move_row = new_sel.start.row;
+		}
+	}
+
 	if (range_equal (&ss->user, &new_sel))
 		return;
 
@@ -464,7 +483,6 @@ sheet_selection_reset_only (Sheet *sheet)
 {
 	GList *list, *tmp;
 
-	g_return_if_fail (sheet != NULL);
 	g_return_if_fail (IS_SHEET (sheet));
 
 	/* Empty the sheets selection */
@@ -503,7 +521,6 @@ sheet_selection_to_string (Sheet *sheet, gboolean include_sheet_name_prefix)
 	GList   *selections;
 	char    *result;
 
-	g_return_val_if_fail (sheet != NULL, NULL);
 	g_return_val_if_fail (IS_SHEET (sheet), NULL);
 	g_return_val_if_fail (sheet->selections, NULL);
 
@@ -535,38 +552,26 @@ sheet_selection_to_string (Sheet *sheet, gboolean include_sheet_name_prefix)
 void
 sheet_selection_ant (Sheet *sheet)
 {
-	GList *l;
-
-	g_return_if_fail (sheet != NULL);
 	g_return_if_fail (IS_SHEET (sheet));
 
-	for (l = sheet->sheet_views; l; l = l->next){
-		SheetControlGUI *sheet_view = l->data;
-
-		sheet_view_selection_ant (sheet_view);
-	}
+	SHEET_FOREACH_CONTROL (sheet, control,
+		sheet_view_selection_ant (control););
 }
 
 void
 sheet_selection_unant (Sheet *sheet)
 {
-	GList *l;
-
-	g_return_if_fail (sheet != NULL);
 	g_return_if_fail (IS_SHEET (sheet));
 
-	for (l = sheet->sheet_views; l; l = l->next){
-		SheetControlGUI *sheet_view = l->data;
-
-		sheet_view_selection_unant (sheet_view);
-	}
+	SHEET_FOREACH_CONTROL (sheet, control,
+		sheet_view_selection_unant (control););
 }
 
 gboolean
 sheet_selection_copy (WorkbookControl *wbc, Sheet *sheet)
 {
 	SheetSelection *ss;
-	g_return_val_if_fail (sheet != NULL, FALSE);
+
 	g_return_val_if_fail (IS_SHEET (sheet), FALSE);
 	g_return_val_if_fail (sheet->selections, FALSE);
 
@@ -599,7 +604,6 @@ sheet_selection_cut (WorkbookControl *wbc, Sheet *sheet)
 	 *        We only store the src, paste does the move.
 	 */
 
-	g_return_val_if_fail (sheet != NULL, FALSE);
 	g_return_val_if_fail (IS_SHEET (sheet), FALSE);
 	g_return_val_if_fail (sheet->selections, FALSE);
 
@@ -620,10 +624,10 @@ sheet_selection_cut (WorkbookControl *wbc, Sheet *sheet)
 /**
  * selection_get_ranges:
  * @sheet: the sheet.
- * @allow_intersection : Divide the selection into nonoverlappign subranges.
+ * @allow_intersection : Divide the selection into nonoverlapping subranges.
  */
 GSList *
-selection_get_ranges (Sheet *sheet, gboolean const allow_intersection)
+selection_get_ranges (Sheet const *sheet, gboolean const allow_intersection)
 {
 	GList  *l;
 	GSList *proposed = NULL;
@@ -946,7 +950,6 @@ selection_apply (Sheet *sheet, SelectionApplyFunc const func,
 	GList *l;
 	GSList *proposed = NULL;
 
-	g_return_if_fail (sheet != NULL);
 	g_return_if_fail (IS_SHEET (sheet));
 
 	if (allow_intersection) {
@@ -1050,13 +1053,16 @@ selection_contains_colrow (Sheet *sheet, int colrow, gboolean is_col)
 	return FALSE;
 }
 
-/*
+/**
  * selection_foreach_range :
  * @sheet : The whose selection is being iterated.
  * @from_start : Iterate from start to end or end to start.
  * @range_cb : A function to call for each sheet.
  * @user_data :
  *
+ * Iterate through the ranges in a selection.
+ * NOTE : The function assumes that the callback routine does NOT change the
+ * selection list.  This can be changed in the future if it is a requirement.
  */
 gboolean
 selection_foreach_range (Sheet *sheet, gboolean from_start,
@@ -1067,7 +1073,6 @@ selection_foreach_range (Sheet *sheet, gboolean from_start,
 {
 	GList *l;
 
-	g_return_val_if_fail (sheet != NULL, FALSE);
 	g_return_val_if_fail (IS_SHEET (sheet), FALSE);
 
 	if (from_start)
@@ -1229,20 +1234,16 @@ sheet_selection_walk_step (Sheet *sheet,
 ColRowSelectionType
 sheet_col_selection_type (Sheet const *sheet, int col)
 {
-	SheetSelection *ss;
 	GList *l;
 	int ret = COL_ROW_NO_SELECTION;
 
-	g_return_val_if_fail (sheet != NULL, COL_ROW_NO_SELECTION);
 	g_return_val_if_fail (IS_SHEET (sheet), COL_ROW_NO_SELECTION);
 
-	if (sheet->selections == NULL ||
-	    sheet->new_object != NULL ||
-	    sheet->current_object != NULL)
+	if (sheet->selections == NULL)
 		return COL_ROW_NO_SELECTION;
 
 	for (l = sheet->selections; l != NULL; l = l->next){
-		ss = l->data;
+		SheetSelection *ss = l->data;
 
 		if (ss->user.start.col > col ||
 		    ss->user.end.col < col)
@@ -1261,20 +1262,16 @@ sheet_col_selection_type (Sheet const *sheet, int col)
 ColRowSelectionType
 sheet_row_selection_type (Sheet const *sheet, int row)
 {
-	SheetSelection *ss;
 	GList *l;
 	int ret = COL_ROW_NO_SELECTION;
 
-	g_return_val_if_fail (sheet != NULL, COL_ROW_NO_SELECTION);
 	g_return_val_if_fail (IS_SHEET (sheet), COL_ROW_NO_SELECTION);
 
-	if (sheet->selections == NULL ||
-	    sheet->new_object != NULL ||
-	    sheet->current_object != NULL)
+	if (sheet->selections == NULL)
 		return COL_ROW_NO_SELECTION;
 
-	for (l = sheet->selections; l != NULL; l = l->next){
-		ss = l->data;
+	for (l = sheet->selections; l != NULL; l = l->next) {
+		SheetSelection *ss = l->data;
 
 		if (ss->user.start.row > row ||
 		    ss->user.end.row < row)
@@ -1290,12 +1287,13 @@ sheet_row_selection_type (Sheet const *sheet, int row)
 	return ret;
 }
 
-/*
+/**
  * sheet_selection_full_cols :
- *
  * @sheet :
+ * @col   :
  *
  * returns TRUE if all of the selected cols in the selection fully selected ?
+ *         and the selection contains the specified col.
  */
 gboolean
 sheet_selection_full_cols (Sheet const *sheet, int col)
@@ -1303,7 +1301,6 @@ sheet_selection_full_cols (Sheet const *sheet, int col)
 	GList *l;
 	gboolean found = FALSE;
 
-	g_return_val_if_fail (sheet != NULL, FALSE);
 	g_return_val_if_fail (IS_SHEET (sheet), FALSE);
 
 	for (l = sheet->selections; l != NULL; l = l->next){
@@ -1317,12 +1314,14 @@ sheet_selection_full_cols (Sheet const *sheet, int col)
 
 	return found;
 }
-/*
+
+/**
  * sheet_selection_full_rows :
- *
  * @sheet :
+ * @row   :
  *
- * returns TRUE if all of the selected rows in the selection fully selected ?
+ * returns TRUE if all of the selected rows in the selection are fully selected
+ *         and the selection contains the specified row.
  */
 gboolean
 sheet_selection_full_rows (Sheet const *sheet, int row)
@@ -1330,10 +1329,9 @@ sheet_selection_full_rows (Sheet const *sheet, int row)
 	GList *l;
 	gboolean found = FALSE;
 
-	g_return_val_if_fail (sheet != NULL, FALSE);
 	g_return_val_if_fail (IS_SHEET (sheet), FALSE);
 
-	for (l = sheet->selections; l != NULL; l = l->next){
+	for (l = sheet->selections; l != NULL; l = l->next) {
 		SheetSelection const *ss = l->data;
 		Range const *r = &ss->user;
 		if (r->start.col != 0 || r->end.col < SHEET_MAX_COLS - 1)
@@ -1344,4 +1342,3 @@ sheet_selection_full_rows (Sheet const *sheet, int row)
 
 	return found;
 }
-
