@@ -7,6 +7,7 @@
 gboolean    sheet_is_all_selected        (Sheet const * const sheet);
 gboolean    sheet_is_cell_selected       (Sheet const * const sheet, int col, int row);
 gboolean    sheet_is_range_selected      (Sheet const * const sheet, Range const *r);
+gboolean    sheet_is_full_range_selected (Sheet const * const sheet, Range const *r);
 void        sheet_selection_extend_to    (Sheet *sheet, int col, int row);
 void        sheet_selection_extend       (Sheet *sheet, int count, gboolean jump_to_boundaries,
 					  gboolean const horizontal);
@@ -45,8 +46,9 @@ typedef void (*SelectionApplyFunc) (Sheet *sheet, Range const *, gpointer closur
 void selection_apply (Sheet *sheet, SelectionApplyFunc const func,
 		      gboolean allow_intersection,
 		      void *closure);
-GSList  *selection_get_ranges (Sheet * sheet, gboolean const allow_intersection);
-gboolean selection_check_for_array (Sheet const * sheet, GSList const *selection);
+gboolean selection_check_for_array (Sheet const *sheet, GSList const *selection);
+GSList  *selection_get_ranges      (Sheet const *sheet,
+				    gboolean allow_intersection);
 
 /* export the selection */
 char       *selection_to_string    (Sheet *sheet,
