@@ -15,8 +15,10 @@ typedef gboolean (*SheetControlGUISlideHandler) (SheetControlGUI *scg, int col,
 struct _SheetControlGUI {
 	GtkTable  table;
 
-	Sheet            *sheet;
-	WorkbookControlGUI     *wbcg;
+	Sheet          	*sheet;
+	GHashTable  	*object_views;
+	WorkbookControlGUI	*wbcg;
+
 	GtkWidget        *canvas;
 	GtkWidget	 *select_all_btn;
 	GnomeCanvas      *col_canvas, *row_canvas;
@@ -24,6 +26,10 @@ struct _SheetControlGUI {
 
 	/* Object group */
 	GnomeCanvasGroup *object_group;
+	SheetObject	 *new_object;	/* A newly created object that has yet to be realized */
+	SheetObject	 *current_object;
+	SheetObject	 *drag_object;
+	void        	 *active_object_frame;	/* FIXME remove this */
 
 	/* Selection group */
 	GnomeCanvasGroup *selection_group;
@@ -47,8 +53,19 @@ struct _SheetControlGUI {
 	int        sliding;	/* a gtk_timeout tag, -1 means not set */
 	int        sliding_col, sliding_row;
 	int        sliding_x, sliding_y;
+
+	/* Comments */
+	struct {
+		CellComment	*selected;
+		GtkWidget	*item;	/* TODO : make this a canvas item with an arrow */
+		int		 timer;
+	} comment;
 };
 
+typedef struct {
+	GtkTableClass parent_class;
+} SheetControlGUIClass;
+
 GtkType          sheet_view_get_type              (void);
 GtkWidget       *sheet_view_new                   (Sheet *sheet);
 
@@ -63,14 +80,6 @@ void             sheet_view_redraw_headers        (SheetControlGUI *scg,
 						   gboolean const col, gboolean const row,
 						   Range const * r /* optional == NULL */);
 
-void             sheet_view_hide_cursor           (SheetControlGUI *scg);
-void             sheet_view_show_cursor           (SheetControlGUI *scg);
-
-GnomeCanvasItem *sheet_view_comment_create_marker (SheetControlGUI *scg,
-						   int col, int row);
-void             sheet_view_comment_relocate      (SheetControlGUI *scg,
-						   int col, int row,
-						   GnomeCanvasItem *o);
 void             sheet_view_set_header_visibility (SheetControlGUI *scg,
 						   gboolean col_headers_visible,
 						   gboolean row_headers_visible);
@@ -81,29 +90,36 @@ void             sheet_view_selection_ant         (SheetControlGUI *scg);
 void             sheet_view_selection_unant       (SheetControlGUI *scg);
 
 void             sheet_view_adjust_preferences    (SheetControlGUI *scg);
-
 void             sheet_view_update_cursor_pos	  (SheetControlGUI *scg);
 
 StyleFont *      sheet_view_get_style_font        (Sheet const *sheet,
 						   MStyle const *mstyle);
 
+void	 sheet_view_stop_sliding  (SheetControlGUI *scg);
 gboolean sheet_view_start_sliding (SheetControlGUI *scg,
 				   SheetControlGUISlideHandler slide_handler,
 				   gpointer user_data,
 				   int col, int row, int dx, int dy);
-void sheet_view_stop_sliding (SheetControlGUI *scg);
 
-void scg_visible_spans_regen (SheetControlGUI *scg);
+void scg_mode_edit		(SheetControlGUI *scg);
+void scg_mode_edit_object	(SheetControlGUI *scg, SheetObject *so);
+void scg_mode_create_object	(SheetControlGUI *scg, SheetObject *so);
 
-typedef struct {
-	GtkTableClass parent_class;
-} SheetControlGUIClass;
+void scg_context_menu		(SheetControlGUI *scg, GdkEventButton *event,
+				 gboolean is_col, gboolean is_row);
+void scg_object_register	(SheetObject *so, GnomeCanvasItem *view);
+void scg_object_widget_register (SheetObject *so, GtkWidget *widget,
+				 GnomeCanvasItem *view);
+void scg_object_calc_position	(SheetControlGUI *scg, SheetObject *so, double *coords);
+void scg_object_view_position	(SheetControlGUI *scg, SheetObject *so, double *coords);
+void scg_object_update_bbox	(SheetControlGUI *scg, SheetObject *so,
+				 GnomeCanvasItem *so_view, double const *offset);
+void scg_comment_select		(SheetControlGUI *scg, CellComment *cc);
+void scg_comment_display	(SheetControlGUI *scg, CellComment *cc);
+void scg_comment_unselect	(SheetControlGUI *scg, CellComment *cc);
 
-/*
- * These actually belong in sheet.h, but the structure dependency
- * forces me to put them here
- */
-SheetControlGUI *sheet_new_sheet_view    (Sheet *sheet);
+/* FIXME : Move these around to a mor ereasonable location */
+SheetControlGUI *sheet_new_sheet_view (Sheet *sheet);
 void       sheet_detach_sheet_view (SheetControlGUI *scg);
 
 #endif /* GNUMERIC_SHEET_CONTROL_GUI_H */
