@@ -3,14 +3,13 @@
  *
  * Daniel Veillard <Daniel.Veillard@w3.org>
  *
- * $Id: xml-io.h,v 1.19 2000/11/16 23:00:27 michael Exp $
+ * $Id: xml-io.h,v 1.20 2000/12/01 18:26:43 jody Exp $
  */
 
 #ifndef GNUMERIC_XML_IO_H
 #define GNUMERIC_XML_IO_H
 
-#include "sheet.h"
-#include "sheet-object.h"
+#include "gnumeric.h"
 #include "gnome-xml/tree.h"
 #include "gnome-xml/xmlmemory.h"
 
@@ -30,10 +29,6 @@ typedef gboolean     (*XmlSheetObjectWriteFn) (xmlNodePtr   cur,
 					       gpointer     user_data);
 typedef SheetObject *(*XmlSheetObjectReadFn)  (xmlNodePtr   tree,
 					       Sheet       *sheet,
-					       double       x1,
-					       double       y1,
-					       double       x2,
-					       double       y2,
 					       gpointer     user_data);
 
 int        gnumeric_xml_read_workbook   (IOContext *context,
